!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!***********************************************************
	subroutine initialize_TEV_tables()
!***********************************************************
	implicit none
	integer i,j,m,n,imax,jmax,ntot,exp,obs
	integer Sneut_tab,Schar_tab,S_tab,Dneut_tab,index,twoDtab
	real*8 mh1dummy,mh2dummy

#include "input_cb.h"
#include "tables-indexing-tev_cb.h"
#include "tables-data-tev_cb.h"

! remark: S95_1d(1,..) or S95_2d(1,..) are the predicted limits tables
!         S95_1d(2,..) or S95_2d(2,..) are the observed limits tables
! for easier reading define identifiers:
	parameter(exp = 1)
	parameter(obs = 2)

! fit function for BR_SM(H->bb) needed to convert tb-limits in sigma x BR-ratios
        double precision SMBR_Hbb

	write(*,*)'Tevatron/LHC-Constraints: initialization of data tables'


! start values for Mhmin_overall/Mhmax_overall (min/max higher/lower than any realistic value)
	Mhmin_overall=10000d0
	Mhmax_overall=0d0


c intitialize counters for switched-on TEV tables
	Sneut_tab=0
	Schar_tab=0
	S_tab=0
	Dneut_tab=0
	twoDtab=0
	index=0

	tev_Sneut_id(-1)=0


	do i=1,(TEV_NSneutCHN+TEV_NScharCHN+TEV_NDCHN)
	  analysis_is_2d(i)=.FALSE.	
	enddo

! initialize tables for the different channels
	write(*,*)
        write(*,*)'single neutral Higgs searches:'


! 1) channel: p pbar -> ZH -> llbb
	write(*,*)'reading tables for channel p pbar -> ZH->llbb'
!>> obsolete
! c) D0 with 2.3fb^-1 (D0 note 5570)
! c) D0 with 4.2 fb^-1 (D0 note 5876) D0_ZH_llbb_3_*
! c) D0 with 6.2 fb^-1 (D0 note 6089) D0_ZH_llbb_4_*
! a) CDF with 2.4 fb^-1 (CDF note 9475)
! a) CDF with 2.7 fb^-1 (www-cdf.fnal.gov/physics/new/hdg/results/zhllbb_081024/index.htm) CDF_ZH_llbb_3_*
! a) CDF with 4.1 fb^-1 (CDF note 9889) CDF_ZH_llbb_4_*
! b) CDF with 1 fb^-1  (hep-ex/0807.4493)
! b) CDF with 2.7 fb^-1  (hep-ex/0908.3534) CDF_ZH_llbb_pub_2_*
!<<

#ifdef CDF10235
	if(whichexpt .eq. 'onlyP') then
	nCDF10235=-1
	else
	index=index+1
	nCDF10235=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! a) CDF with 5.7 fb^-1 (CDF note 10235)
	write(*,*)'  CDF with 5.7 fb^-1 (CDF note 10235)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/CDF_ZH_llbb_5_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_ZH_llbb_5_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
! remark: S95_1d(1,..) is the predicted/expected limits table
!         S95_1d(2,..) is the observed limits table
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif	


#ifdef CDF1009_3047
	index=index+1
	nCDF1009_3047=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! b) CDF with 4.1 fb^-1  (hep-ex/1009.3047)
	write(*,*)'  CDF with 4.1 fb^-1  (hep-ex/1009.3047)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/CDF_ZH_llbb_pub_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_ZH_llbb_pub_3_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef D06166
        if(whichexpt .eq. 'onlyP') then
	nD06166=-1
	else

	index=index+1
	nD06166=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! c) D0 with 8.6 fb^-1 (D0 note 6166)
	write(*,*)'  D0 with 8.6 fb^-1 (D0 note 6166)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06166_ZH_llbb_5_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06166_ZH_llbb_5_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D01008_3564
	index=index+1
	nD01008_3564=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! c) D0 with 4.2 fb^-1  (hep-ex/1008.3564)
	write(*,*)'  D0 with 4.2 fb^-1  (hep-ex/1008.3564)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_ZH_llbb_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ZH_llbb_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!2) channel: p pbar -> WH/ZH -> bb + missing E_T (SM combined)
	write(*,*)'reading tables for channel p pbar -> WH/ZH -> bb + missing E_T'
!>> obsolete
!a) CDF with 1 fb^-1 (CDF note 9166)
!a) CDF with 2.1 fb^-1 (CDF note 9483)
!a) CDF with 2.1 fb^-1 (CDF note 9642) CDF_VH_bbmET_3_*
!a) CDF with 3.6 fb^-1 (CDF note 9891) CDF_VH_bbmET_4_*
!   CDF with 5.7 fb^-1 (CDF note 10212) CDF_VH_bbmET_5_*
!d) CDF with 1 fb^-1  (hep-ex/0802.0432) CDF_VH_bbmET_pub_*
!c) D0 with 0.93 fb^-1  (hep-ex/0808.1266) D0_VH_bbmET_pub_*
!b) D0 with 2.1 fb^-1 (D0 note 5586) D0_VH_bbmET_*
!b) D0 with 6.4 fb^-1 (D0 note 6087) D0_VH_bbmET_2_*
!b) D0 with 6.2 fb^-1 (D0 note 6170) D0_D06170_VH_bbmET_3_*
!<<

#ifdef CDF10583
!CDF10583	: p p-bar -> H via HW -> b b-bar + miss. E_T,	
!			     HZ -> b b-bar + miss. E_T, SM combined, CDF with 7.8 fb^-1
!			(CDF note 10583, CDF_VH_bbmET_6_exp.txt  CDF_VH_bbmET_6_obs.txt)
        if(whichexpt .eq. 'onlyP') then
	nCDF10583=-1
	else

	index=index+1
	nCDF10583=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF with 7.8 fb^-1 (CDF note 10583)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/CDF_VH_bbmET_6_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_VH_bbmET_6_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06223
        if(whichexpt .eq. 'onlyP') then
	nD06223=-1
	else

	index=index+1
	nD06223=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) D0 with 8.4 fb^-1 (D0 note 6223)
	write(*,*)'  D0 with 8.4 fb^-1 (D0 note 6223)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06223_VH_bbmET_4_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06223_VH_bbmET_4_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF0911_3935
!CDF0911_3935	: p p-bar -> H via HW -> b b-bar + miss. E_T,	
!			     HZ -> b b-bar + miss. E_T, SM combined, CDF with 2.1 fb^-1
!			(hep-ex/0911.3935, CDF_VH_bbmET_pub_exp.txt  CDF_VH_bbmET_pub_obs.txt)
	index=index+1
	nCDF0911_3935=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!d) CDF with 2.1 fb^-1  (hep-ex/0911.3935)
	write(*,*)'  CDF with 2.1 fb^-1  (hep-ex/0911.3935)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_VH_bbmET_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_VH_bbmET_pub_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D00912_5285
!D00912_5285	: p p-bar -> H via HW -> b b-bar + miss. E_T,
!                            HZ -> b b-bar + miss. E_T, SM combined, D0 with 5.2 fb^-1
!			(hep-ex/0912.5285, D0_VH_bbmET_pub_2_exp.txt  D0_VH_bbmET_pub_2_obs.txt)
!e) D0 with 5.2 fb^-1  (hep-ex/0912.5285)
	write(*,*)'  D0 with 5.2 fb^-1  (hep-ex/0912.5285)'

	index=index+1
	nD00912_5285=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 4. 

	open(10,file=INSTDIR//"/TEVtables/D0_VH_bbmET_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_VH_bbmET_pub_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CDF10596
!CDF10596	: p p-bar -> WH/ZH -> b b-bar + missing E_T, CDF with 7.5 fb^-1
        if(whichexpt .eq. 'onlyP') then
	nCDF10596=-1
	else

	index=index+1
	nCDF10596=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF with 7.5 fb^-1 (CDF note 10596)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10596_VH_bblmET_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10596_VH_bblmET_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


!2b) channel: p p -> WH/ZH -> bb + missing E_T (SM combined)
	write(*,*)'reading tables for channel p p -> WH/ZH -> bb + missing E_T'

#ifdef ATLAS2011_103
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_103=-1
	else

	index=index+1
	nATLAS2011_103=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS with 1.04 fb^-1 (ATLAS-CONF-2011-103)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=130d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011103_Atlas_VH_Vbb_1.04fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef CMS11_031
        if(whichexpt .eq. 'onlyP') then
	nCMS11_031=-1
	else

	index=index+1
	nCMS11_031=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CMS with 4.7 fb^-1 (CMS-PAS-HIG-11-031)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=135d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/11031_CMS_VH-bb_BDT_4.7fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif




!3) channel: p pbar -> WH -> lnubb
	write(*,*)'reading tables for channel p pbar -> WH->lnubb'
!>> obsolete
!b) D0 with 1.7 fb^-1 (D0 note 5472)
!c) CDF with 2.7 fb^-1 (CDF note 9463)
!b) D0 with 2.7 fb^-1 (D0 note 5828) D0_WH_lnubb_2_*
!b) D0 with 5.0 fb^-1 (D0 note 5972) D0_WH_lnubb_3_*
!b) D0 with 5.3 fb^-1 (D0 note 6092) D0_WH_lnubb_4_*
!d) D0 with 1.1 fb^-1  (hep-ex/0808.1970, PRL 102(2009)051803) D0_WH_lnubb_pub_*
!e) CDF with 1.0 fb^-1  (hep-ex/0803.3493, PRD 78(2008)032008) 
!c) CDF with 2.7 fb^-1 (CDF note 9596) CDF_WH_lnubb_4_*
!c) CDF with 4.3 fb^-1 (http://www-cdf.fnal.gov/physics/new/hdg/results/whlnubb_090814/WH4.3fb.html)
!   	CDF_WH_lnubb_5_*
!c) CDF with 4.8 fb^-1 (CDF note 10068) CDF_WH_lnubb_6_*
!   CDF with 5.6 fb^-1 (CDF note 10217), CDF_WH_lnubb_7_*
!<<

#ifdef D06220
        if(whichexpt .eq. 'onlyP') then
	nD06220=-1
	else

	index=index+1
	nD06220=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) D0 with 8.5 fb^-1 (D0 note 6220) 
	write(*,*)'  D0 with 8.5 fb^-1 (D0 note 6220)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11

	open(10,file=INSTDIR//"/TEVtables/D0_D06220_WH_lnubb_5_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06220_WH_lnubb_5_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF10239
!CDF10239	: p p-bar -> WH -> l nu b b-bar, CDF with 5.7 fb^-1
!			(CDF note 10239, CDF_WH_lnubb_8_exp.txt  CDF_WH_lnubb_8_obs.txt)
        if(whichexpt .eq. 'onlyP') then
	nCDF10239=-1
	else

	index=index+1
	nCDF10239=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF with 5.7 fb^-1 (CDF note 10239)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/CDF_WH_lnubb_8_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_WH_lnubb_8_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D01012_0874
	index=index+1
	nD01012_0874=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!d) D0 with 5.3 fb^-1  (hep-ex/1012.0874)
	write(*,*)'  D0 with 5.3 fb^-1  (hep-ex/1012.0874)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11

	open(10,file=INSTDIR//"/TEVtables/D0_WH_lnubb_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_WH_lnubb_pub_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF0906_5613
	index=index+1
	nCDF0906_5613=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!e) CDF with 2.7 fb^-1  (hep-ex/0906.5613)
	write(*,*)'  CDF with 2.7 fb^-1  (hep-ex/0906.5613)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11

	open(10,file=INSTDIR//"/TEVtables/CDF_WH_lnubb_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_WH_lnubb_pub_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



!4) channel: p pbar -> H -> WW (/ZZ) (= often SM combined)
	write(*,*)'reading tables for channel ppH -> WW (/ZZ)'
!>> obsolete
!a) CDF 1.9 fb^-1
!b) D0 note 5489
!c) D0  with 2.3 fb^-1 (D0 note 5624)
!h) D0 6.7 fb^-1 (D0 note 6082) D0_ppH_WW_ll_4_*
!d) CDF 2.4 fb^-1 (CDF note 9236)
!g) CDF 3.6 fb^-1 (www-cdf.fnal.gov/physics/new/hdg/results/hwwmenn_090227/)
!g) CDF 4.8 fb^-1 (CDF note 9887, www-cdf.fnal.gov/physics/new/hdg/results/hwwmenn_090814/)
!		CDF_ppH_WW_6_*
!   CDF 5.3 fb^-1, SM combined (CDF note 10102) CDF_ppH_WW_7_*
!<< obsolete


#ifdef D05757
        if(whichexpt .eq. 'onlyP') then
	nD05757=-1
	else

	index=index+1
	nD05757=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!e) D0 3.0 fb^-1
	write(*,*)'  D0 table for ppH -> WW -> ll with 3.0 fb^-1 (D0 note 5757)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 18. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF0809_3930
!CDF0809_3930	: p p-bar -> H -> W W, CDF with 3.0 fb^-1 (Phys.Rev.Lett.102(2009)021802)
!                       (hep-ex/0809.3930, CDF_ppH_WW_pub_exp.txt  CDF_ppH_WW_pub_obs.txt)
	index=index+1
	nCDF0809_3930=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!f) CDF 3.0 fb^-1
	write(*,*)'  CDF table for 3.0 fb^-1  (hep-ex/0809.3930)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 10. 

	open(10,file=INSTDIR//"/TEVtables/CDF_ppH_WW_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_ppH_WW_pub_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF_D0_1005_3216
!CDF_D0_1005_3216	: p p-bar -> single H -> W W, CDF & D0 with 4.8/5.4 fb^-1 (hep-ex/1005.3216)
!			  absolute limit in pikobarn	
!                       (CDF_D0_singleH_WW_pub-abs-limit_exp.txt  CDF_D0_singleH_WW_pub-abs-limit_obs.txt)
	index=index+1
	nCDF_D0_1005_3216=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF & D0 analysis with 4.8/5.4 fb^-1  (hep-ex/1005.3216)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 39.

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_singleH_WW_pub-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_singleH_WW_pub-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D06219singHWW
!D06219singHWW	: p p-bar -> single H -> W W, D0 with 8.1 fb^-1 (D0 6219)
!			  absolute limit in pikobarn

	if(whichexpt .eq. 'onlyP') then
	nD06219singHWW=-1
	else

	index=index+1
	nD06219singHWW=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 analysis for  pp-bar -> single H -> WW with 8.1 fb^-1 (D0 note 6219)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06219_singleH_WW-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06219_singleH_WW-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif



#ifdef CDF10599singHWW
!CDF10599singHWW	: p p-bar -> single H -> W W, D0 with 8.2 fb^-1 (CDF 10599)
!			  absolute limit in pikobarn
	if(whichexpt .eq. 'onlyP') then
	nCDF10599singHWW=-1
	else

	index=index+1
	nCDF10599singHWW=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF analysis for  pp-bar -> single H -> WW with 8.2 fb^-1 (CDF note 10599)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10599_singleH_WW-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10599_singleH_WW-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif






#ifdef CDF10599
!CDF10599  : p p-bar -> H + X -> W W + X via single H,
!				  HZ, HW, VBF, CDF with 8.2 fb^-1 
!                       (CDF note 10599, CDF_CDF10599_ppH_WW_8_*)
        if(whichexpt .eq. 'onlyP') then
	nCDF10599=-1
	else

	index=index+1
	nCDF10599=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! CDF 8.2 fb^-1, SM combined (CDF note 10599)
	write(*,*)'  CDF with 8.2 fb^-1, SM combined (CDF note 10599)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 19. 

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10599_ppH_WW_8_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10599_ppH_WW_8_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF1001_4468
!CDF1001_4468  : p p-bar -> H + X -> W W + X via single H,
!				  HZ, HW, VBF, CDF with 4.8 fb^-1 
!                       (hep-ex/1001.4468, CDF_ppH_WW_pub_2_exp.txt  CDF_ppH_WW_pub_2_obs.txt)
	index=index+1
	nCDF1001_4468=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF with 4.8 fb^-1, SM combined  (hep-ex/1001.4468)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 19. 

	open(10,file=INSTDIR//"/TEVtables/CDF_ppH_WW_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_ppH_WW_pub_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D05871
!h) D0 note 5871, p p-bar -> H + X -> W W + X-> l l + X via single H,
!		HZ, HW, VBF, D0 with 3.0-4.2 fb^-1
!			(D0 note 5871, D0_ppH_WW_ll_3_exp.txt  D0_ppH_WW_ll_3_obs.txt)
        if(whichexpt .eq. 'onlyP') then
	nD05871=-1
	else

	index=index+1
	nD05871=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 table for ppH -> WW + X -> ll + X with 4.2 fb^-1 (D0 note 5871)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 18. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_3_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06219
!D06219		: p p-bar -> H + X -> W W/ Z Z + X-> e mu + X 
!			via single H, HZ, HW, VBF, D0 with 8.1 fb^-1
!			(D0 note 6219, D0_ppH_WW_ll_5_exp.txt  D0_ppH_WW_ll_5_obs.txt)
!h) D0 8.1 fb^-1 (D0 note 6219) 
        if(whichexpt .eq. 'onlyP') then
	nD06219=-1
	else

	index=index+1
	nD06219=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 table for ppH -> WW/ZZ + X -> ll + X with 8.1 fb^-1 (D0 note 6219)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 18. 

	open(10,file=INSTDIR//"/TEVtables/D0_D06219_ppH_WW_ll_5_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06219_ppH_WW_ll_5_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06179
!D06179		: p p-bar -> H + X -> W W + X-> tau mu + X 
!			via single H, HZ, HW, VBF, D0 with 7.3 fb^-1
!			(D0 note 6179, D0_D06179_SM_WW_* )
!h) D0 7.3 fb^-1 (D0 note 6179) 
        if(whichexpt .eq. 'onlyP') then
	nD06179=-1
	else

	index=index+1
	nD06179=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 table for ppH -> WW + X -> tau mu + X with 7.3 fb^-1 (D0 note 6179)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06179_SM_WW_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06179_SM_WW_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06183
!D06183		: p p-bar -> H + X -> W W/gamma gamma/tau tau/ Z Z + X
!			via single H, HZ, HW, VBF, D0 with 8.2 fb^-1
!			(D0 note 6183)
!h) D0 8.2 fb^-1 (D0 note 6183) 
        if(whichexpt .eq. 'onlyP') then
	nD06183=-1
	else

	index=index+1
	nD06183=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 table for ppH -> WW/gamma gamma/tau tau/ZZ + X -> ll + X with 8.2 fb^-1 (D0 note 6183)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=130d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06183_SM_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06183_SM_3_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif







#ifdef D01001_4481
!D01001_4481		: p p-bar -> H + X -> W W + X-> l l + X via single H,
!				  HZ, HW, VBF, D0 with 5.4 fb^-1
!			(D0 hep-ex/1001.4481, D0_ppH_WW_ll_pub_exp.txt  D0_ppH_WW_ll_pub_obs.txt)
!h) D0 5.4 fb^-1 (hep-ex/1001.4481 = PRL 104 (2010) 061804)
	write(*,*)'  D0 table for ppH -> WW + X -> ll + X with 5.4 fb^-1 (D0 hep-ex/1001.4481)'

	index=index+1
	nD01001_4481=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 18. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_WW_ll_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF_D0_1001_4162
!CDF_D0_1001_4162  : p p-bar -> H + X -> W W + X via single H,
!				  HZ, HW, VBF, CDF & D0 with 4.8-5.4 fb^-1, SM combined
!                       (hep-ex/1001.4162, CDF_D0_ppH_WW_pub_exp.txt CDF_D0_ppH_WW_pub_obs.txt)
	index=index+1
	nCDF_D0_1001_4162=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF & D0 with 4.8-5.4 fb^-1, SM combined  (hep-ex/1001.4162)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=130d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_ppH_WW_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_ppH_WW_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CDF_D0_1108_3331
!CDF_D0_1108_3331  : p p-bar ->  g g -> H -> WW abs. limit in pikobarn with 8.2/8.1 fb^-1, SM combined (hep-ex/1108.3331)
	index=index+1
	nCDF_D0_1108_3331=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF & D0 p p-bar -> gg -> H -> WW, abs. limit in pb with 8.2/8.1 fb^-1, SM combined  (hep-ex/1108.3331)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_1108_3331_SM-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_1108_3331_SM-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!4b) channel: p p -> WW/ZZ (SM combined)
	write(*,*)'reading tables for channel p p -> WW/ZZ -> l nu l nu'

#ifdef ATLAS2011_134
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_134=-1
	else

	index=index+1
	nATLAS2011_134=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + 0jet -> WW -> l nu l nu with 1.7 fb^-1 (ATLAS-CONF-2011-134)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011134_Atlas_H-WW-lnulnu_1.7fb-1_interpol.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef CMS1102_5429
	index=index+1
	nCMS1102_5429=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CMS pp -> H + 0jet -> WW -> l nu l nu with 0.041 fb^-1 (hep-ex/1102.5429)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=130d0
	Mhmax(S_tab)=400d0
	sep(S_tab)=10d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/5429_CMS_H-WW_36pb-1_rat_interpol.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif





#ifdef ATLAS1109_3357
	index=index+1
	nATLAS1109_3357=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + X, H -> ZZ/WW -> l nu l nu, SM combined with 1.04 fb^-1  (hep-ex/1109.3357)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=200d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=20d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/3357_Atlas_H-ZZ-llnunu_1.04fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef ATLAS2011_148
      if(whichexpt .eq. 'onlyP') then
	nATLAS2011_148=-1
	else

	index=index+1
	nATLAS2011_148=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + X, H -> ZZ/WW -> l nu l nu, SM combined with 2.05 fb^-1 (ATLAS-CONF-2011-148)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=200d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=20d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011148_Atlas_H-ZZ-lnulnu_2.05fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
      Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
      endif
#endif

#ifdef ATLAS1112_2577
	 index=index+1
	 nATLAS1112_2577=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  ATLAS pp -> H + X, H -> ZZ/WW -> l nu l nu, SM combined with 2.05 fb^-1 (hep-ex/1112.2577)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=300d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2577_Atlas_H-WW-lnulnu_2.05fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CMS1202_1489
	 index=index+1
	 nCMS1202_1489=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  CMS pp -> H + X, H -> ZZ/WW -> l nu l nu, SM combined with 4.6 fb^-1 (hep-ex/1202.1489)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=5d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/11024_CMS_H-WW-lnulnu_4.6fb-1_interpol.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS1202_3478
	 index=index+1
	 nCMS1202_3478=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  CMS pp -> H + X, H -> ZZ/(WW) -> l nu l nu, SM combined with 4.6 fb^-1 (hep-ex/1202.3478)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=250d0
	 Mhmax(S_tab)=590d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/11026_CMS_H-ZZ-llnunu_4.6fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



!4c) channel: p p -> WW -> l nu q q (= often SM combined)
	write(*,*)'reading tables for channel p p -> WW -> l nu q q'

#ifdef ATLAS2011_052
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_052=-1
	else

	index=index+1
	nATLAS2011_052=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + 0jet -> WW -> lnu qq with 0.035 fb^-1 (ATLAS-CONF-2011-052)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=220d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=20d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011052_Atlas_H-WW_35pb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef ATLAS1109_3615
	index=index+1
	nATLAS1109_3615=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + X, H -> WW -> l nu q q with 1.04 fb^-1  (hep-ex/1109.3615)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=240d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=20d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/3615_Atlas_H-WW-lnuqq_1.04fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif




!4d) channel: p p -> ZZ -> llqq (SM combined)
	write(*,*)'reading tables for channel p p -> ZZ -> l nu q q'

#ifdef ATLAS1108_5064
	index=index+1
	nATLAS1108_5064=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + X, H -> ZZ -> llqq, SM combined with 1.04 fb^-1  (hep-ex/1108.5064)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=200d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=10d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/5064_Atlas_H-ZZ-llqq_1.04fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS1202_1416low
	index=index+1
	nCMS1202_1416low=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CMS pp -> H + X, H -> ZZ -> llqq, SM combined with 4.6 fb^-1, low mass (hep-ex/1202.1416)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=130d0
	Mhmax(S_tab)=164d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/110271_CMS_H-ZZ-llqq_4.6fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS1202_1416hi
	index=index+1
	nCMS1202_1416hi=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CMS pp -> H + X, H -> ZZ -> llqq, SM combined with 4.6 fb^-1, high mass (hep-ex/1202.1416)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=200d0
	Mhmax(S_tab)=600d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/110272_CMS_H-ZZ-llqq_4.6fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif




!4e) channel: p p -> ZZ -> llll (SM combined)
	write(*,*)'reading tables for channel p p -> ZZ -> 4l'

c>> obsolete
! ATLAS2011_162 : pp -> H + X, H -> ZZ -> 4l, SM combined with 4.8 fb^-1 (ATLAS-CONF-2011-162) : 2011162_Atlas_H-ZZ-4l_4.8fb-1.txt
c<<
#ifdef ATLAS1202_1415
	 index=index+1
	 nATLAS1202_1415=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  ATLAS pp -> H + X, H -> ZZ -> 4l, SM combined with 4.8 fb^-1 (hep-ex/1202.1415)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/1415_Atlas_H-ZZ-4l_4.8fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef ATLAS1109_5945
	 index=index+1
	 nATLAS1109_5945=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  ATLAS pp -> H + X, H -> ZZ -> 4l, SM combined with 2.1 fb^-1  (hep-ex/1109.5945)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=5d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/ATLAS_1109.5945_H-ZZ_2.1fb-1-exp.txt")
	 open(20,file=INSTDIR//"/LHCtables/ATLAS_1109.5945_H-ZZ_2.1fb-1-obs.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
	   read(20,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(exp,S_tab,i)
	   read(20,*)Mh1dummy,S95_1d(obs,S_tab,i)
         enddo

         close(10)	 	
         close(20)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS1202_1997
	 index=index+1
	 nCMS1202_1997=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  CMS pp -> H + X, H -> ZZ -> 4l, SM combined with 4.7 fb^-1 (hep-ex/1202.1997)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/11025_CMS_H-ZZ-4l_4.7fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



!5) channel: SM combined limits
!>> obsolete
!g) CDF SM combined limit with 2.0 - 4.8 fb^-1, August 2009 (CDF note 9897) CDF_SM_2_*
!CDF9248	: p p-bar -> H -> tau tau via HW with W -> j j, 
!			     HZ with Z -> j j,
!			     single H, VBF, SM combined 
!	(CDF note 9248), CDF_SM_tautau_*
!b) CDF H -> tau tau SM combined limits with 2.3 fb^-1 (CDF note 10133),
!	CDF_SM_tautau_2_*
!<< obsolete
#ifdef CDF8961_D05536
	index=index+1
	nCDF8961_D05536=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) CDF & D0 SM combined limits of Dec 2007
	write(*,*)'reading tables for the CDF & D0 SM combined limits  (hep-ex/0712.2383)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 19. 

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_SM_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_SM_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF10439
!CDF10439	: p p-bar -> H -> tau tau via HW with W -> j j, 
!			     HZ with Z -> j j,
!			     single H, VBF, SM combined 
!			(CDF note 10439, CDF_SM_tautau_3_* )
!b) CDF H -> tau tau SM combined limits with 6.0 fb^-1 (CDF note 10439)
        if(whichexpt .eq. 'onlyP') then
	nCDF10439=-1
	else

	index=index+1
	nCDF10439=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'reading tables for the CDF H -> tau tau SM combined limits with 6.0 fb^-1 (CDF note 10439)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/CDF_SM_tautau_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_SM_tautau_3_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D00903_4800
!D00903_4800	: p p-bar -> (W)H -> (tau nu)bb or (jj)tau tau,
!			     (Z)H -> (tau tau)bb,
!			     single H, H via VBF, H -> tau tau, SM combined 
!			(D0 hep-ex/0903.4800, D0_SM_tautau_pub_exp.txt  D0_SM_tautau_pub_obs.txt)
!b2) D0 H -> tau tau SM combined limits with 2 fb^-1 (D0 hep-ex/0903.4800 = PRL 102(2009)251801)
	write(*,*)'reading tables for the D0 H -> tau tau SM combined limits with 1 fb^-1,  (hep-ex/0903.4800)'

	index=index+1
	nD00903_4800=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! information about how data is stored in file:	 
	Mhmin(S_tab)=105d0
	Mhmax(S_tab)=145d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 5. 

	open(10,file=INSTDIR//"/TEVtables/D0_SM_tautau_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_SM_tautau_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D05845
!D05845	: p p-bar -> (W)H -> (jj)tau tau,
!			     (Z)H -> (tau tau)jj or (jj)tau tau,
!			     single H, H via VBF, H -> tau tau, SM combined with 4.9 fb^-1
!			(D0 note 5845, D0_SM_tautau_exp.txt  D0_SM_tautau_obs.txt)
!b3) D0 H -> tau tau SM combined limits with 4.9 fb^-1 (D0 note 5845)
        if(whichexpt .eq. 'onlyP') then
	nD05845=-1
	else

	index=index+1
	nD05845=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'reading tables for the D0 H -> tau tau SM combined limits with 4.9 fb^-1 (D0 note 5845)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=105d0
	Mhmax(S_tab)=145d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 5. 

	open(10,file=INSTDIR//"/TEVtables/D0_SM_tautau_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_SM_tautau_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif




#ifdef CDF9290_D05645
	index=index+1
	nCDF9290_D05645=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!c) CDF & D0 SM combined limits of Apr 2008
	write(*,*)'reading tables for the CDF & D0 SM combined limits with 1-2.4 fb^-1  (hep-ex/0804.3423)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 19. 

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_SM_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_SM_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF9465_D05754
	index=index+1
	nCDF9465_D05754=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!d) CDF & D0 SM combined limits of August 2008
	write(*,*)'reading tables for the CDF & D0 SM combined limits with 3 fb^-1  (hep-ex/0808.0534)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=155d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 10. 

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_SM_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_SM_3_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D00712_0598
	index=index+1
	nD00712_0598=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!e) D0 SM combined limit with 0.44 fb^-1, published
	write(*,*)'reading tables for the D0 SM combined limit with 0.44 fb^-1 (hep-ex/0712.0598)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 21. 

	open(10,file=INSTDIR//"/TEVtables/D0_SM_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_SM_pub_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF9999
!CDF9999	: p p-bar -> HW -> l nu b b-bar,
!			     HZ -> nu nu b b-bar, l l b b-bar,
!			     HV -> b b-bar j j,
!			     H via single H/HW/HZ/VBF, H -> W W
!			     H via single H/HW/HZ/VBF, H -> tau tau 
!			     SM combined 
!			(CDF note 9999, CDF_SM_3_exp.txt  CDF_SM_3_obs.txt)
        if(whichexpt .eq. 'onlyP') then
	nCDF9999=-1
	else

	index=index+1
	nCDF9999=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!g) CDF SM combined limit with 2.0 - 4.8 fb^-1, August 2009
	write(*,*)'reading tables for the CDF SM combined limit (CDF note 9999)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 21. 

	open(10,file=INSTDIR//"/TEVtables/CDF_SM_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_SM_3_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06008
        if(whichexpt .eq. 'onlyP') then
	nD06008=-1
	else

	index=index+1
	nD06008=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!h) D0 SM combined limit with 2.1 - 5.4 fb^-1
	write(*,*)'reading tables for the D0 SM combined limit with 2.1-5.4 fb^-1 (D0 note 6008)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 21. 

	open(10,file=INSTDIR//"/TEVtables/D0_SM_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_SM_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF9998_D05983
	index=index+1
	nCDF9998_D05983=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!i) CDF & D0  combined limit with 2.1-5.4 fb^-1 (hep-ex/0911.3930)
	write(*,*)'reading tables for the CDF & D0 SM combined limits with 2.1-5.4 fb^-1 (hep-ex/0911.3930)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be ??. 

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_SM_5_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_SM_5_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*) 
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF10241_D06096
	index=index+1
	nCDF10241_D06096=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!i) CDF & D0  combined limit with up to 5.9/6.7 fb^-1 (hep-ex/1007.4587)
	write(*,*)'reading tables for the CDF & D0 SM combined limits with up to 5.9/6.7 fb^-1 (hep-ex/1007.4587)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be ??. 

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_SM_6_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_SM_6_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*) 
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



#ifdef CDF10010
!CDF10010	: p p-bar -> WH/ZH/H via VB, H -> bb
!			(CDF note 10010, CDF_VHnVBF_bb_exp.txt CDF_VHnVBF_bb_obs.txt)
! CDF H -> b b SM combined limits with 4 fb^-1 (CDF note 10010)
        if(whichexpt .eq. 'onlyP') then
	nCDF10010=-1
	else

	index=index+1
	nCDF10010=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'reading tables for the CDF H -> b b SM combined limits with 4 fb^-1 (CDF note 10010)'

! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_VHnVBF_bb_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_VHnVBF_bb_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06171
        if(whichexpt .eq. 'onlyP') then
	nD06171=-1
	else

	index=index+1
	nD06171=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!h) D0 SM combined limit with 5.4 fb^-1
	write(*,*)'reading tables for the D0 SM combined limit with 5.4 fb^-1 (D0 note 6171)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=105d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06171_SM_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06171_SM_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06229
        if(whichexpt .eq. 'onlyP') then
	nD06229=-1
	else

	index=index+1
	nD06229=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!h) D0 SM combined limit with 4.3-8.6 fb^-1
	write(*,*)'reading tables for the D0 SM combined limit with 4.3-8.6 fb^-1 (D0 note 6229)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D06229_SM_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06229_SM_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF10500
        if(whichexpt .eq. 'onlyP') then
	nCDF10500=-1
	else

	index=index+1
	nCDF10500=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! CDF SM combined limit (WH -> lnutautau & ZH -> lltautau) with 6.2 fb^-1
	write(*,*)'reading tables for the CDF SM combined limit (WH -> lnutautau & ZH -> lltautau) with 6.2 fb^-1 (CDF note 10500)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10500_VH_tautau_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10500_VH_tautau_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF10573
        if(whichexpt .eq. 'onlyP') then
	nCDF10573=-1
	else

	index=index+1
	nCDF10573=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! CDF ZH -> ZWW -> 4l + X & H + X -> ZZ +X  -> 4l + X etc. SM combined limit with 8.2 fb^-1 (CDF note 10573)
	write(*,*)'reading tables for the CDF ZH -> ZWW -> 4l + X & H + X -> ZZ +X  -> 4l + X etc. SM combined limit with 8.2 fb^-1 (CDF note 10573)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=120d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10573_ZZnZWW_llll_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10573_ZZnZWW_llll_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF_D0_1103_3233
	index=index+1
	nCDF_D0_1103_3233=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!i) CDF & D0  combined limit with up to 7.1/8.2 fb^-1 (hep-ex/1007.4587)
	write(*,*)'reading tables for the CDF & D0 SM combined limits with up to 7.1/8.2 fb^-1 (hep-ex/1103.3233)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=130d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_1103_3233_SM_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_1103_3233_SM_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*) 
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF_D0_1107_5518
	index=index+1
	nCDF_D0_1107_5518=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!i) CDF & D0  combined limit with up to 8.2/8.6 fb^-1 (hep-ex/1107.5518)
	write(*,*)'reading tables for the CDF & D0 SM combined limits with up to 8.2/8.6 fb^-1 (hep-ex/1107.5518)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_1107_5518_SM_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_1107_5518_SM_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*) 
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF_D0_1107_5518bb
	index=index+1
	nCDF_D0_1107_5518bb=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!i) CDF & D0  combined limit with up to 8.2/8.6 fb^-1 H->bb SM combined (hep-ex/1107.5518)
	write(*,*)'reading tables for the CDF & D0 H->bb SM combined limits with up to 8.2/8.6 fb^-1 (hep-ex/1107.5518)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_D0_1107_5518_SM_bb_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_D0_1107_5518_SM_bb_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*) 
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!LHC analyses
#ifdef ATLAS2011_112
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_112=-1
	else
	 index=index+1
	 nATLAS2011_112=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS SM comined limit with up to 1.21 fb^-1 (ATLAS-CONF-2011-112)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2011112_Atlas_SMcombined_1.04-1.21fb-1_interpol.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
        endif
#endif

#ifdef ATLAS2011_135
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_135=-1
	else
	 index=index+1
	 nATLAS2011_135=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS SM comined limit with up to 2.3 fb^-1 (ATLAS-CONF-2011-135)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2011135_Atlas_SMcombined_1-2.3fb-1_interpol.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
        endif
#endif

#ifdef ATLAS1106_2748
	 index=index+1
	 nATLAS1106_2748=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS SM comined limit with up to 0.04 fb^-1  (hep-ex/1106.2748)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=5d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2748_Atlas_SMcombined_40pb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef ATLAS2011_163
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_163=-1
	else
	 index=index+1
	 nATLAS2011_163=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS SM comined limit with up to 4.9 fb^-1 (ATLAS-CONF-2011-163)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=0.5d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2011163_Atlas_SMcombined_4.9fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef ATLAS1202_1408
	 index=index+1
	 nATLAS1202_1408=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS SM comined limit with up to 4.9 fb^-1 (hep-ex/1202.1408)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/1408_Atlas_SMcombined_4.9fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef ATLAS2011_157_CMS11_023
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_157_CMS11_023=-1
	else
	 index=index+1
	 nATLAS2011_157_CMS11_023=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the ATLAS & CMS SM comined limit with up to 2.3 fb^-1 (ATLAS-CONF-2011-157/CMS PAS HIG-11-023)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/2011157_Atlas_CMS_SMcombined_2.3fb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
        endif
#endif

#ifdef CMS11_011
        if(whichexpt .eq. 'onlyP') then
	nCMS11_011=-1
	else
	 index=index+1
	 nCMS11_011=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the CMS SM comined limit with up to 1.1 fb^-1 (CMS PAS HIG-11-011)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=10d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/11011_CMS_SMcomb_1.1fb-1_interpol.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
        endif
#endif


#ifdef CMS1202_1488
	 index=index+1
	 nCMS1202_1488=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'reading tables for the CMS SM comined limit with up to 4.8 fb^-1 (hep-ex/1202.1488)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=110d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=1d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/CMS_1202.1488_SMcombined_4.8fb-1-exp.txt")
	 open(11,file=INSTDIR//"/LHCtables/CMS_1202.1488_SMcombined_4.8fb-1-obs.txt")

! first 5 lines are not needed
         do i=1,5
           read(10,*)
           read(11,*) 
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(exp,S_tab,i)
           read(11,*)Mh1dummy,S95_1d(obs,S_tab,i)
         enddo

         close(10)    
         close(11)

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif




!6) channel: p pbar -> b H, H-> b b
!>> obsolete
!a) CDF tanb-table with 1.9 fb^-1 (CDF note 9284) CDF_bH_bb_tb_limit_*
!   D0 absolute sigma x BR table in pikobarn for 1fb^-1 (hep-ex/0805.3556) D0_bH_bb-abs-limit_*
!<< obsolete

	write(*,*)'reading tables for p pbar -> bH, H -> bb'

#ifdef CDF10105
!CDF10105	: p p-bar -> b H, H -> b b-bar, CDF with 2.5 fb^-1
!			(CDF note 10105, CDF_bH_bb_tb_limit_2_exp.txt  CDF_bH_bb_tb_limit_2_obs.txt)
        if(whichexpt .eq. 'onlyP') then
	nCDF10105=-1
	else

	index=index+1
	nCDF10105=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CDF tanb-table with 2.5 fb^-1 (CDF note 10105)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=210d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 13. 

	open(10,file=INSTDIR//"/TEVtables/CDF_bH_bb_tb_limit_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_bH_bb_tb_limit_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

! reading tb-limits and converting to (sigma x BR)_limit/(sigma x BR)_SM
! see CDF note 10105
!   (sigma x BR)_limit                                           0.9
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2 x ------------------
!     (sigma x BR)_SM                                       BR_SM(H->bb,m_H)
!
! As this function is steeply rising with m_H it is not ideal for interpolating 
! between given points. We choose here (*)
!
!   (sigma x BR)_limit    
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2 x 0.9
!        sigma_SM                                       

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)**2*2d0*0.9d0
!left out for choice (*) : /SMBR_Hbb(Mh1dummy)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
          S95_1d(2,S_tab,i)=S95_1d(2,S_tab,i)**2*2d0*0.9d0
!left out for choice (*) : /SMBR_Hbb(Mh1dummy)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

!>> removed
!!b) CDF absolute sigma x BR table in pikobarn for 1.9fb^-1 (CDF note 9284)
!<< removed


#ifdef D05726
        if(whichexpt .eq. 'onlyP') then
	nD05726=-1
	else

	index=index+1
	nD05726=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!c) D0
	write(*,*)'  D0 tanb-table (D0 note 5726)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=220d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 14. 

	open(10,file=INSTDIR//"/TEVtables/D0_bH_bb_tb_limit_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_bH_bb_tb_limit_2_obs.txt")

! reading tb-limits and converting to (sigma x BR)_limit/(sigma x BR)_SM
! see D0 note 5726 (currently unclear if factor of 2 below is right)
!   (sigma x BR)_limit                                           0.9
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2 x ------------------
!     (sigma x BR)_SM                                       BR_SM(H->bb,m_H)
!
! As this function is steeply rising with m_H it is not ideal for interpolating 
! between given points. We choose here (*):
!
!   (sigma x BR)_limit    
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2 x 0.9
!        sigma_SM                                       
        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)**2*2d0*0.9d0
!left out for choice (*) : /SMBR_Hbb(Mh1dummy)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
          S95_1d(2,S_tab,i)=S95_1d(2,S_tab,i)**2*2d0*0.9d0
!left out for choice (*) : /SMBR_Hbb(Mh1dummy)
        enddo

        close(10)	 	
	close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D01011_1931
	index=index+1
	nD01011_1931=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!d) D0
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 5.2 fb^-1,  (hep-ex/1011.1931)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_bH_bb-abs-limit_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_bH_bb-abs-limit_pub_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF1106_4782
	index=index+1
	nCDF1106_4782=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!d) CDF
	write(*,*)'  CDF absolute sigma x BR table in pikobarn for 2.6 fb^-1,  (hep-ex/1106.4782)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=350d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF1106_4782_bH_bb_pub-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF1106_4782_bH_bb_pub-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
!  /!\ : files have data in femtobarn 
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)/1000d0
	  S95_1d(2,S_tab,i)=S95_1d(2,S_tab,i)/1000d0
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!7) channel: p pbar -> H -> tau tau
!>> obsolete
!b) CDF absolute sigma x BR table in pikobarn for 1.8 fb^-1 (CDF note 9071)
!a) D0 1 fb^-1 (hep-ex/0805.2491) D0_ppH_tautau_pub-abs-limit_*
!d) CDF & D0 combined limits for ppH -> tau tau, absolute sigma x BR table in pikobarn 
!   for 1.8 fb^-1 (CDF note 9071) & 2.2 fb^-1 (D0 note 5740), CDF note 9888, D0 note 5980
!<<
	write(*,*)'reading tables for channel p pbar -> H +X, H -> tau tau'

#ifdef D01106_4555
	index=index+1
	nD01106_4555=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) D0 5.4 fb^-1 (hep-ex/1106.4555)
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 5.4 fb^-1 (hep-ex/1106.4555)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 22. 

	open(10,file=INSTDIR//"/TEVtables/D0_D01106_4555_ppH_tautau_pub_2-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D01106_4555_ppH_tautau_pub_2-abs-limit_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF0906_1014
	index=index+1
	nCDF0906_1014=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) CDF absolute sigma x BR table in pikobarn for 1.8 fb^-1 published (CDF0906_1014)
	write(*,*)'  CDF absolute sigma x BR table in pikobarn for 1.8 fb^-1  (hep-ex/0906.1014)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=250d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 17. 

	open(10,file=INSTDIR//"/TEVtables/CDF_ppH_tautau-abs-limit_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_ppH_tautau-abs-limit_pub_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D05740
        if(whichexpt .eq. 'onlyP') then
	nD05740=-1
	else

	index=index+1
	nD05740=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!c) D0 absolute sigma x BR table in pikobarn for 2.2 fb^-1 (D0 note 5740)
        write(*,*)'  D0 absolute sigma x BR table in pikobarn for 2.2 fb^-1 (D0 note 5740)'
! information about how data is stored in file:  
        Mhmin(S_tab)=90d0
        Mhmax(S_tab)=300d0
        sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 22. 

        open(10,file=INSTDIR//"/TEVtables/D0_ppH_tautau-abs-limit_exp.txt")
        open(11,file=INSTDIR//"/TEVtables/D0_ppH_tautau-abs-limit_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF10099_D06063
!CDF10099_D06063 : p p-bar -> H -> tau tau, CDF & D0 combined with up to 2.2 fb^-1 absolute limits
!                  	(CDF note 10099, D0 note 6063, 
!		  	 CDF_D0_ppH_tautau-abs-limit_2_exp.txt CDF_D0_ppH_tautau-abs-limit_2_obs.txt)
	index=index+1
	nCDF10099_D06063=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! CDF & D0 combined limits for ppH -> tau tau, absolute sigma x BR table in pikobarn 
!   with up to 2.2 fb^-1 CDF note 10099, D0 note 5980 (hep-ex/1003.3363)
	write(*,*)'  CDF  & D0 combined limits (absolute sigma x BR in pikobarn) (hep-ex/1003.3363)'
! information about how data is stored in file:  
        Mhmin(S_tab)=90d0
        Mhmax(S_tab)=200d0
        sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 12. 

        open(10,file=INSTDIR//"/TEVtables/CDF_D0_ppH_tautau-abs-limit_2_exp.txt")
        open(11,file=INSTDIR//"/TEVtables/CDF_D0_ppH_tautau-abs-limit_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



!7b) channel: p p -> H + X, H -> tau tau
	write(*,*)'reading tables for channel p p -> H + X, H -> tau tau'

#ifdef ATLAS2011_133
      if(whichexpt .eq. 'onlyP') then
	nATLAS2011_133=-1
	else

	index=index+1
	nATLAS2011_133=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS pp -> H + X, H -> tau tau, SM combined with 1.06 fb^-1 (ATLAS-CONF-2011-133)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=140d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011133_Atlas_H-tautau-ll4nu_1.06fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
      Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
      endif
#endif

#ifdef ATLAS1107_5003
! remark: The ggh-limit is a bit more conservative than the bbh-limit.
!         Hence, we take the former.
	 index=index+1
	 nATLAS1107_5003=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  ATLAS pp -> H, H -> tau tau with 0.036 fb^-1, absolute sigma x BR table in pikobarn  (hep-ex/1107.5003)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=90d0
	 Mhmax(S_tab)=300d0
	 sep(S_tab)=10d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

c more conservative choice:
	 open(10,file=INSTDIR//"/LHCtables/5003_Atlas_ggh_h-tautau_36pb-1.txt")
c less conservative choice:
cnot	 open(10,file=INSTDIR//"/LHCtables/5003_Atlas_bbh_h-tautau_36pb-1.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef ATLAS2011_132
        if(whichexpt .eq. 'onlyP') then
	nATLAS2011_132=-1
	else
	 index=index+1
	 nATLAS2011_132=index

	 Sneut_tab=Sneut_tab+1
	 S_tab=S_tab+1
	 tev_id_Sneut(Sneut_tab)=index
	 tev_Sid_Sneut(Sneut_tab)=S_tab
	 tev_Sneut_id(index)=Sneut_tab

	 write(*,*)'  ATLAS pp -> H, H -> tau tau with 1.06 fb^-1, absolute sigma x BR table in pikobarn (ATLAS-CONF-2011-132)'
! information about how data is stored in file:	 
	 Mhmin(S_tab)=90d0
	 Mhmax(S_tab)=600d0
	 sep(S_tab)=10d0

	 ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

c more conservative choice out of ggH- and bbH-limit:
	 open(10,file=INSTDIR//"/LHCtables/2011132_Atlas_conserv_h-tautau_1.06fb-1_interpol.txt")

! first 5 lines are not needed
         do i=1,5
	   read(10,*)
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
         enddo

         close(10)	 	

	 Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
        endif
#endif

#ifdef CMS11_029SM
        if(whichexpt .eq. 'onlyP') then
	nCMS11_029SM=-1
	else
	index=index+1
	nCMS11_029SM=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)' CMS pp -> H + X, H -> tau tau, SM combined with 4.6 fb^-1 (CMS-PAS-HIG-11-029)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=145d0
	sep(S_tab)=5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/11029_CMS_H-tautau_4.6fb-1_SM.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef CMS1104_1619
	index=index+1
	nCMS1104_1619=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)' CMS pp -> H + X, H -> tau tau, with 0.036 fb^-1, absolute sigma x BR table in pikobarn (hep-ex/1104.1619)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=500d0
	sep(S_tab)=10d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/CMS1104_1619_H-tautau_36pb-1_interpol.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS11_029
        if(whichexpt .eq. 'onlyP') then
	nCMS11_029=-1
	else
	index=index+1
	nCMS11_029=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)' CMS pp -> H + X, H -> tau tau, with 4.6 fb^-1, absolute sigma x BR table in pikobarn (CMS-PAS-HIG-11-029)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=500d0
	sep(S_tab)=10d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/11029_CMS_H-tautau_4.6fb-1_MSSM_interpol.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif




!8) channel: p pbar -> WH -> WWW
	write(*,*)'reading tables for channel p pbar -> WH->WWW'
!>> obslete
!b) CDF with 1.9 fb^-1 (CDF note 7307 version 2)
!a) D0 absolute sigma x BR table in pikobarn with 1 fb^-1 (D0 note 5485)
!<<

#ifdef D05873
        if(whichexpt .eq. 'onlyP') then
	nD05873=-1
	else

	index=index+1
	nD05873=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) D0 with 3.6 fb^-1 (D0 note 5873)
	write(*,*)'  D0 with 3.6 fb^-1 (D0 note 5873)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=120d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=20d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 5. 

	open(10,file=INSTDIR//"/TEVtables/D0_WH_WWW_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_WH_WWW_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF7307v3
        if(whichexpt .eq. 'onlyP') then
	nCDF7307v3=-1
	else

	index=index+1
	nCDF7307v3=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) CDF with 2.7 fb^-1 (CDF note 7307 version 3)
	write(*,*)'  CDF with 2.7 fb^-1 (CDF note 7307 version 3)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 10. 

	open(10,file=INSTDIR//"/TEVtables/CDF_WH_WWW_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_WH_WWW_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


!8B) channel: VH, H-> -> VVV -> same sign dilepton(e,mu) + X SM combined (V=W,Z)
	write(*,*)'reading tables for channel VH, H-> -> VVV -> same sign dilepton(e,mu) + X SM combined (V=W,Z)'
!>> obslete
!a) D0 with 5.4 fb^-1 (D0 note 6091)
!<<

#ifdef D01107_1268
	index=index+1
	nD01107_1268=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) D0 with 5.3 fb^-1 (D0 hep-ex/1107.1268)
	write(*,*)'  D0 with 5.3 fb^-1 (hep-ex/1107.1268)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=115d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D01107_1268_VH_VVV_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D01107_1268_VH_VVV_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif



!9) channel: p pbar -> H + X, H -> gamma gamma
	write(*,*)'reading tables for channel: p pbar -> H + X, H -> gamma gamma'
!>> obsolete
!a) D0 with 2.68 fb^-1 (D0 note 5737)
!   D0 with 4.2 fb^-1 (D0 note 6177), D0_ppH_gamgam_4_*
!   CDF SM combined with 5.4 fb^-1 (CDF note 10065), /CDF_SM_gamgam_*
!<< obsolete

#ifdef D06177
!D06177		: p p-bar -> H -> gamma gamma via single H,
!			     HZ, HW, VBF, D0 with 8.2 fb^-1
!			(D0 note 6177, D0_D06177_ppH_gamgam_*.txt
        if(whichexpt .eq. 'onlyP') then
	nD06177=-1
	else

	index=index+1
	nD06177=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  D0 with 8.2 fb^-1 (D0 note 6177)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=2.5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 21. 

	open(10,file=INSTDIR//"/TEVtables/D0_D06177_ppH_gamgam_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06177_ppH_gamgam_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


!temporary removed #ifdef D00803_1514
!temporary removed 	index=index+1
!temporary removed 	nD00803_1514=index
!temporary removed
!temporary removed 	Sneut_tab=Sneut_tab+1
!temporary removed 	S_tab=S_tab+1
!temporary removed 	tev_id_Sneut(Sneut_tab)=index
!temporary removed 	tev_Sid_Sneut(Sneut_tab)=S_tab
!temporary removed 	tev_Sneut_id(index)=Sneut_tab
!temporary removed  
!temporary removed !b) D0 with 1.1 fb^-1
!temporary removed 	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 1.1 fb^-1  (D0 hep-ex/0803.1514)'
!temporary removed ! information about how data is stored in file:	 
!temporary removed 	Mhmin(S_tab)=70d0
!temporary removed 	Mhmax(S_tab)=150d0
!temporary removed 	sep(S_tab)=10d0
!temporary removed 
!temporary removed         ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
!temporary removed ! ntot is expected to be 9. 
!temporary removed 
!temporary removed 	open(10,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub-abs-limit_exp.txt")
!temporary removed 	open(11,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub-abs-limit_obs.txt")
!temporary removed 
!temporary removed         do i=1,ntot
!temporary removed 	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
!temporary removed           read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
!temporary removed         enddo
!temporary removed 
!temporary removed         close(10)    
!temporary removed         close(11)
!temporary removed 
!temporary removed 	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
!temporary removed         Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
!temporary removed #endif


#ifdef D00901_1887
	index=index+1
	nD00901_1887=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) D0 with 2.7 fb^-1
	write(*,*)'  D0 with 2.7 fb^-1  (D0 hep-ex/0901.1887)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF10485
        if(whichexpt .eq. 'onlyP') then
	nCDF10485=-1
	else

	index=index+1
	nCDF10485=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

! CDF SM combined with 7.0 fb^-1 
	write(*,*)'  CDF SM combined with 7.0 fb^-1 (CDF note 10485)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_SM_gamgam_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_SM_gamgam_2_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef CDFD0_1107_4960
	index=index+1
	nCDFD0_1107_4960=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) CDF & D0 with 7.0 and 8.2 fb^-1
	write(*,*)'  CDF & D0 with 7.0 and 8.2  (CDF & D0 hep-ex/1107.4960)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_gamgam_pub_2_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!9b) channel: p p -> H + X, H -> gamma gamma
	write(*,*)'reading tables for channel: p p -> H + X, H -> gamma gamma'

c>> obsolete
! ATLAS2011_161 : ATLAS SM combined with 4.9 fb^-1 (ATLAS-CONF-2011-161) : 2011161_Atlas_H-gaga_4.9fb-1.txt
c<<
#ifdef ATLAS1202_1414
	index=index+1
	nATLAS1202_1414=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS SM combined with 4.9 fb^-1 (hep-ex/1202.1414)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/1414_Atlas_H-gaga_4.9fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef ATLAS1108_5895
	index=index+1
	nATLAS1108_5895=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  ATLAS SM combined with 1.08 fb^-1  (hep-ex/1108.5895)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=1d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/5895_Atlas_H-gaga_1.08fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

#ifdef CMS1202_1487
	index=index+1
	nCMS1202_1487=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	write(*,*)'  CMS SM combined with 4.8 fb^-1 (hep-ex/1202.1487)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=110d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=0.5d0

	ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	 open(10,file=INSTDIR//"/LHCtables/CMS_1202.1487_H-gaga_4.8fb-1-exp.txt")
	 open(11,file=INSTDIR//"/LHCtables/CMS_1202.1487_H-gaga_4.8fb-1-obs.txt")

! first 5 lines are not needed
         do i=1,5
           read(10,*)
           read(11,*) 
         enddo

         do i=1,ntot
	   read(10,*)Mh1dummy,S95_1d(exp,S_tab,i)
           read(11,*)Mh1dummy,S95_1d(obs,S_tab,i)
         enddo

         close(10)    
         close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


!10) channel: p pbar -> b H, H-> tau tau
	write(*,*)'reading tables for p pbar -> bH, H -> tau tau'
!>> obsolete
!a) D0 with 0.328 fb^-1  (hep-ex/0811.0024), absolute sigma x BR table in pikobarn
!a) D0 with 2.7 fb^-1  (hep-ex/0912.0968), absolute sigma x BR table in pikobarn
!<<
#ifdef D01106_4885
	index=index+1
	nD01106_4885=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) D0 with 7.3 fb^-1  (hep-ex/1106.4885), absolute sigma x BR table in pikobarn
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 7.3 fb^-1,  (hep-ex/1106.4885)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=320d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D01106_4885_bH_tautau_pub-abs-limit_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D01106_4885_bH_tautau_pub-abs-limit_3_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

! results in file are in fb -> conversion to pb :
        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)/1000d0
	  S95_1d(2,S_tab,i) =S95_1d(2,S_tab,i)/1000d0
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef D05985
        if(whichexpt .eq. 'onlyP') then
	nD05985=-1
	else

	index=index+1
	nD05985=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b) D0 with 2.7 fb^-1 (D0 note 5985), absolute sigma x BR table in pikobarn
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 2.7 fb^-1 (D0 note 5985)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=320d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 24. 

	open(10,file=INSTDIR//"/TEVtables/D0_bH_tautau-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_bH_tautau-abs-limit_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06083abslim
        if(whichexpt .eq. 'onlyP') then
	nD06083abslim=-1
	else

	index=index+1
	nD06083abslim=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b2) D0 with 4.3 fb^-1 (D0 note 6083), absolute sigma x BR table in pikobarn
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 4.3 fb^-1, (D0 note 6083)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=320d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 24. 

	open(10,file=INSTDIR//"/TEVtables/D0_bH_tautau-abs-limit_2_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_bH_tautau-abs-limit_2_obs.txt")

! first 5 lines are not needed	 
        do i=1,5
	  read(10,*)  	 
	  read(11,*)  	 
        end do	 	

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D05974
        if(whichexpt .eq. 'onlyP') then
	nD05974=-1
	else

	index=index+1
	nD05974=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b2) D0 with 3.7 fb^-1 (D0 note 5974), absolute sigma x BR table in pikobarn
	write(*,*)'  D0 absolute sigma x BR table in pikobarn for 3.7 fb^-1, (D0 note 5974)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=300d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_D05974_bH_tautau-abs-limit_3_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D05974_bH_tautau-abs-limit_3_obs.txt")

! first 5 lines are not needed	 
        do i=1,5
	  read(10,*)  	 
	  read(11,*)  	 
        end do	 	

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef D06083
        if(whichexpt .eq. 'onlyP') then
	nD06083=-1
	else

	index=index+1
	nD06083=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!b2) D0 with 4.3 fb^-1 (D0 note 6083), limit on tb^2 
	write(*,*)'  D0 with 4.3 fb^-1, limit on tb^2 (D0 note 6083)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=200d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/D0_bH_tautau_tb_limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_bH_tautau_tb_limit_obs.txt")

! reading tb-limits and converting to (sigma x BR)_limit/(sigma)_SM
! see D0 note 6083 
!   (sigma x BR)_limit                                                    1
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2 x 1/10 x ------------------
!     (sigma x BR)_SM                                              BR_SM(H->bb,m_H)
!
! As this function is steeply rising with m_H it is not ideal for interpolating 
! between given points. We choose here:
!
!   (sigma x BR)_limit    
!  --------------------(m_H) = ( tanb_limit(m_H) )^2 x 2/10
!        sigma_SM                                       


! first 5 lines are not needed	 
        do i=1,5
	  read(10,*)  	 
	  read(11,*)  	 
        end do	 	

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)*2d0/10d0
	  S95_1d(2,S_tab,i)=S95_1d(2,S_tab,i)*2d0/10d0
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif






!11) channel: ttH -> ttbb
	write(*,*)'reading tables for channel: ttH -> ttbb'

#ifdef D05739
        if(whichexpt .eq. 'onlyP') then
	nD05739=-1
	else

	index=index+1
	nD05739=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) D0 with 2.1 fb^-1
	write(*,*)'  D0 with 2.1 fb^-1 (D0 note 5739)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=105d0
	Mhmax(S_tab)=155d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 6. 

	open(10,file=INSTDIR//"/TEVtables/D0_ttH_ttbb_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ttH_ttbb_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CDF10574
        if(whichexpt .eq. 'onlyP') then
	nCDF10574=-1
	else

	index=index+1
	nCDF10574=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

!a) CDF with 7.5 fb^-1
	write(*,*)'  CDF with 7.5 fb^-1 (CDF note 10574)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=100d0
	Mhmax(S_tab)=170d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_CDF10574_ttH_ttbb_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_CDF10574_ttH_ttbb_obs.txt")

! first 5 lines are not needed
        do i=1,5
          read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif



!12) channel: ppH -> Zgamma
	write(*,*)'reading tables for channel: ppH -> Z gamma'

#ifdef D00806_0611
	index=index+1
	nD00806_0611=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab


!a) D0 with 1.0 fb^-1
	write(*,*)'  D0 with 1.0 fb^-1  (hep-ex/0806.0611)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=120d0
	Mhmax(S_tab)=320d0
	sep(S_tab)=20d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 11. 

	open(10,file=INSTDIR//"/TEVtables/D0_ppH_Zgamma_pub-abs-limit_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_ppH_Zgamma_pub-abs-limit_obs.txt")

! first 5 lines are not needed	 
        do i=1,5
	  read(10,*)  	 
	  read(11,*)  	 
        end do	 	

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
! results in file are in fb -> conversion to pb :
	  S95_1d(1,S_tab,i)=S95_1d(1,S_tab,i)/1000d0
	  S95_1d(2,S_tab,i) =S95_1d(2,S_tab,i)/1000d0
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif





	write(*,*)
        write(*,*)'single charged Higgs searches:'

! ch 1) channel: p pbar -> tt, t -> H+ b (& c.c.), H+ -> cs
	write(*,*)'reading tables for p pbar -> tt, t -> H+ b (& c.c.), H+ -> cs'

#ifdef D00908_1811cs
!D00908_1811cs : p pbar -> tt, t -> H+ b (& c.c.), H+ -> cs , D0 with 1 fb^-1
!			(hep-ex/0908.1811, D0_tt_hpmb_cs_pub_exp.txt  D0_tt_hpmb_cs_pub_obs.txt)
        index=index+1
	nD00908_1811cs=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

!a) D0 with 1.0 fb^-1
	write(*,*)'  D0 with 1.0 fb^-1  (hep-ex/0908.1811)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=80d0
	Mhmax(S_tab)=155d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 16. 

	open(10,file=INSTDIR//"/TEVtables/D0_tt_hpmb_cs_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_tt_hpmb_cs_pub_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF0907_1269low
        index=index+1
	nCDF0907_1269low=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

!b) CDF with 2.2 fb^-1
	write(*,*)'  CDF with 2.2 fb^-1  (hep-ex/0907.1269), low mass part'
! information about how data is stored in file:	 
	Mhmin(S_tab)=60d0
	Mhmax(S_tab)=70d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
! ntot is expected to be 2. 

	open(10,file=INSTDIR//"/TEVtables/CDF_tt_hpmb_cs_low_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_tt_hpmb_cs_low_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif


#ifdef CDF0907_1269hi
        index=index+1
	nCDF0907_1269hi=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

!b) CDF with 2.2 fb^-1
	write(*,*)'  CDF with 2.2 fb^-1  (hep-ex/0907.1269), high mass part'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=150d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_tt_hpmb_cs_hi_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/CDF_tt_hpmb_cs_hi_pub_obs.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
          read(11,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif






! ch 2) channel: p pbar -> tt, t -> H+ b (& c.c.), H+ -> tau nu
        write(*,*)'reading tables for p pbar -> tt, t -> H+ b (& c.c.), H+ -> tau nu'

#ifdef CDF7712
	if(whichexpt .eq. 'onlyP') then
	nCDF7712=-1
	else
        index=index+1
	nCDF7712=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  CDF with 0.192 fb^-1  (CDF note 7712)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=80d0
	Mhmax(S_tab)=160d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_t-Hplusb_tauonicHM_192pb_7712.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef CDF8353
	if(whichexpt .eq. 'onlyP') then
	nCDF8353=-1
	else
        index=index+1
	nCDF8353=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  CDF with 0.335 fb^-1  (CDF note 8353)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=80d0
	Mhmax(S_tab)=120d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/TEVtables/CDF_t-Hplusb_8353.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif




#ifdef D00908_1811taunu
        index=index+1
	nD00908_1811taunu=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

!a) D0 with 1.0 fb^-1
!D0_tt_hpmb_taunu_pub_exp.txt
!D0_tt_hpmb_taunu_pub_obs.txt
	write(*,*)'  D0 with 1.0 fb^-1  (hep-ex/0908.1811)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=80d0
	Mhmax(S_tab)=155d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1
!	write(*,*)'ntot=',ntot
! ntot is expected to be 16. 

	open(10,file=INSTDIR//"/TEVtables/D0_tt_hpmb_taunu_pub_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_tt_hpmb_taunu_pub_obs.txt")

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(1,S_tab,i)
          read(11,*)Mh1dummy,S95_1d(2,S_tab,i)
        enddo

        close(10)    
        close(11)

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
#endif

!LHC analyses
! ch 3) channel: p p -> tt, t -> H+ b (& c.c.), H+ -> cs
	write(*,*)'reading tables for p p -> tt, t -> H+ b (& c.c.), H+ -> cs'

#ifdef ATLAS2011_094
	if(whichexpt .eq. 'onlyP') then
	nATLAS2011_094=-1
	else
        index=index+1
	nATLAS2011_094=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  ATLAS with 0.035 fb^-1  (ATLAS-CONF-2011-094)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=130d0
	sep(S_tab)=20d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011094_Atlas_Hplus-cs_35pb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


! ch 4) channel: p p -> tt, t -> H+ b (& c.c.), H+ -> tau nu
	write(*,*)'reading tables for p p -> tt, t -> H+ b (& c.c.), H+ -> tau nu'

#ifdef ATLAS2011_138
	if(whichexpt .eq. 'onlyP') then
	nATLAS2011_138=-1
	else
        index=index+1
	nATLAS2011_138=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  ATLAS with 1.03 fb^-1  (ATLAS-CONF-2011-138)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=160d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011138_Atlas_Hp-taunu_1.03fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif

#ifdef ATLAS2011_151
	if(whichexpt .eq. 'onlyP') then
	nATLAS2011_151=-1
	else
        index=index+1
	nATLAS2011_151=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  ATLAS with 1.03 fb^-1  (ATLAS-CONF-2011-151)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=90d0
	Mhmax(S_tab)=160d0
	sep(S_tab)=10d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/2011151_Atlas_chargedH-taunu_1.03fb-1.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


#ifdef CMS11_008
	if(whichexpt .eq. 'onlyP') then
	nCMS11_008=-1
	else
        index=index+1
	nCMS11_008=index	

	Schar_tab=Schar_tab+1
        S_tab=S_tab+1
	tev_id_Schar(Schar_tab)=index
	tev_Sid_Schar(Schar_tab)=S_tab
	tev_Schar_id(index)=Schar_tab

	write(*,*)'  CMS with 1.0 fb^-1  (CMS-PAS-HIG-11-008)'
! information about how data is stored in file:	 
	Mhmin(S_tab)=80d0
	Mhmax(S_tab)=160d0
	sep(S_tab)=5d0

        ntot=nint((Mhmax(S_tab)-Mhmin(S_tab))/sep(S_tab))+1

	open(10,file=INSTDIR//"/LHCtables/11008_CMS_Hplus-taunu_1.1fb-1_interpol.txt")

! first 5 lines are not needed
        do i=1,5
	  read(10,*)
        enddo

        do i=1,ntot
	  read(10,*)Mh1dummy,S95_1d(obs,S_tab,i),S95_1d(exp,S_tab,i)
        enddo

        close(10)	 	

	Mhmin_overall=min(Mhmin_overall,Mhmin(S_tab))
        Mhmax_overall=max(Mhmax_overall,Mhmax(S_tab))
	endif
#endif


c>> double Higgs searches Baustelle
	write(*,*)
        write(*,*)'double neutral Higgs searches:'

c fix common block var for number of single Higgs analyses with 2d tables
	nTEV_S2dTAB=twoDtab

	write(*,*)'reading table for p pbar -> h1 -> h2 h2 -> ..'

#ifdef D0_0905_3381_4mu
	index=index+1
	nD0_0905_3381_4mu=index

	Dneut_tab=Dneut_tab+1
	tev_id_Dneut(Dneut_tab)=index
	tev_Dneut_id(index)=Dneut_tab

	twoDtab=twoDtab+1
	analysis_is_2d(index)=.TRUE.

	write(*,*)'  p pbar -> h1 -> h2 h2 -> 4 mu, D0 with 4.2 fb^-1 (hep-ex/0905.3381)'


c X: mh2 ("mh") [GeV]
	XVALmin(twoDtab)=80D0
        XVALmax(twoDtab)=200D0
	sepX(twoDtab)=5d0
c Y: mh1 ("ma") [GeV]
        YVALmin(twoDtab)=0.2d0
        YVALmax(twoDtab)=3.0d0
	sepY(twoDtab)=0.1d0

	imax=int((XVALmax(twoDtab)-XVALmin(twoDtab))/sepX(twoDtab))
	jmax=int((YVALmax(twoDtab)-YVALmin(twoDtab))/sepY(twoDtab))
	
	open(10,file=INSTDIR//"/TEVtables/D0_D0_0905_3381_h-aa-mumumumu_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D0_0905_3381_h-aa-mumumumu_obs.txt")

c Skip first line in files. Data starts in 2nd line.
        read(10,*)
        read(11,*)

	do i=0,imax  
         read(10,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
c check	write(*,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
         read(11,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
c check	write(*,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
        enddo

! convert original table in femtobarn in pikobarn
	do i=0,imax  
	do j=0,jmax  
          S95_2d(1,twoDtab,i,j)=S95_2d(1,twoDtab,i,j)/1000d0
          S95_2d(2,twoDtab,i,j)=S95_2d(2,twoDtab,i,j)/1000d0
        enddo
        enddo
		
	close(10)
        close(11)
#endif


#ifdef D0_0905_3381_2mu2tau
	index=index+1
	nD0_0905_3381_2mu2tau=index

	Dneut_tab=Dneut_tab+1
	tev_id_Dneut(Dneut_tab)=index
	tev_Dneut_id(index)=Dneut_tab

	twoDtab=twoDtab+1
	analysis_is_2d(index)=.TRUE.

	write(*,*)'  p pbar -> h1 -> h2 h2 -> 2 tau  2 mu, D0 with 4.2 fb^-1 (hep-ex/0905.3381)'


c X: mh2 ("mh") [GeV]
	XVALmin(twoDtab)=85D0
        XVALmax(twoDtab)=200D0
	sepX(twoDtab)=5d0
c Y: mh1 ("ma") [GeV]
        YVALmin(twoDtab)=3.6d0
        YVALmax(twoDtab)=19.0d0
	sepY(twoDtab)=0.2d0

	imax=int((XVALmax(twoDtab)-XVALmin(twoDtab))/sepX(twoDtab))
	jmax=int((YVALmax(twoDtab)-YVALmin(twoDtab))/sepY(twoDtab))
	
	open(10,file=INSTDIR//"/TEVtables/D0_D0_0905_3381_h-aa-tautaumumu_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D0_0905_3381_h-aa-tautaumumu_obs.txt")

c Skip first line in files. Data starts in 2nd line.
        read(10,*)
        read(11,*)

	do i=0,imax  
         read(10,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
c check	 write(*,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
         read(11,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
c check	 write(*,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
        enddo

! convert original table in femtobarn in pikobarn
	do i=0,imax  
	do j=0,jmax  
          S95_2d(1,twoDtab,i,j)=S95_2d(1,twoDtab,i,j)/1000d0
          S95_2d(2,twoDtab,i,j)=S95_2d(2,twoDtab,i,j)/1000d0
        enddo
        enddo
		
	close(10)
        close(11)
#endif

c>> 2d tables
#ifdef D06227
        if(whichexpt .eq. 'onlyP') then
	nD06227=-1
	else

	index=index+1
	nD06227=index

	Sneut_tab=Sneut_tab+1
	S_tab=S_tab+1
	tev_id_Sneut(Sneut_tab)=index
	tev_Sid_Sneut(Sneut_tab)=S_tab
	tev_Sneut_id(index)=Sneut_tab

	twoDtab=twoDtab+1
	tev_Sis2d_Sid(S_tab)=twoDtab
	analysis_is_2d(index)=.TRUE.

	write(*,*)'  D0 search for bh with h->bb or h->tau tau with 7.3 fb^-1 (D0 note 6227)'

check	write(*,*)'twoDtab=',twoDtab

c X: mh [GeV]
	XVALmin(twoDtab)=90D0
        XVALmax(twoDtab)=300D0
	sepX(twoDtab)=10d0

c Y: BR(h -> tau tau) (assumption: BR(h -> tau tau) + BR(h -> bb) =  1
        YVALmin(twoDtab)=0.06d0
        YVALmax(twoDtab)=0.18d0
	sepY(twoDtab)=0.04d0
	
	imax=int((XVALmax(twoDtab)-XVALmin(twoDtab))/sepX(twoDtab))
	jmax=int((YVALmax(twoDtab)-YVALmin(twoDtab))/sepY(twoDtab))
	
	open(10,file=INSTDIR//"/TEVtables/D0_D06227_h-bb_h-tautau_comb_5.2-7.3fb_exp.txt")
	open(11,file=INSTDIR//"/TEVtables/D0_D06227_h-bb_h-tautau_comb_5.2-7.3fb_obs.txt")

c Skip first line in files. Data starts in 2nd line.
        read(10,*)
        read(11,*)

	do i=0,imax  
         read(10,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
ccheck	 write(*,*) Mh1dummy,( S95_2d(1,twoDtab,i,j), j=0,jmax )
         read(11,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
ccheck	 write(*,*) Mh1dummy,( S95_2d(2,twoDtab,i,j), j=0,jmax )
        enddo

! convert original table in femtobarn in pikobarn
	do i=0,imax  
	do j=0,jmax  
          S95_2d(1,twoDtab,i,j)=S95_2d(1,twoDtab,i,j)/1000d0
          S95_2d(2,twoDtab,i,j)=S95_2d(2,twoDtab,i,j)/1000d0
        enddo
        enddo
		
	close(10)
        close(11)
	endif
#endif

c<<


c<< double Higgs searches Baustelle


	write(*,*)'finished reading Tevatron tables'

c	write(*,123) Mhmin_overall,Mhmax_overall
c 123	FORMAT(' Overall mass range of Tevatron tables: [',G10.4,',',G10.4,'] GeV.')
c remark: Mhmin_overall,Mhmax_overall are not used anymore.
        write(*,*)


	nTEV_NSneutCHN=Sneut_tab
	nTEV_NScharCHN=Schar_tab
	nTEV_NSCHN=nTEV_NSneutCHN+nTEV_NScharCHN

c>>check
	if(S_tab .ne. nTEV_NSCHN) then
	  write(*,*)'Something is wrong!!'
	  stop
	endif
c<<
	nTEV_NDCHN=Dneut_tab

c>> check
c	write(*,*)'nTEV_NSneutCHN=',nTEV_NSneutCHN
c        write(*,*)'nTEV_NScharCHN=',nTEV_NScharCHN
c        write(*,*)'nTEV_NSCHN=',nTEV_NSCHN
c        write(*,*)'nTEV_NDCHN=',nTEV_NDCHN
c<<
	write(*,*)'Number of Tevatron analyses :'
	write(*,*)'   single neutral Higgs analyses :',nTEV_NSneutCHN
	write(*,*)'   single charged Higgs analyses :',nTEV_NScharCHN
	write(*,*)'   double neutral Higgs analyses :',nTEV_NDCHN
	write(*,*)'                        total    :',nTEV_NSneutCHN+nTEV_NScharCHN+nTEV_NDCHN
	write(*,*)

	end





! >> include fit functions for SM cross section ratios
#include "cs-ratios/Tevatron.R_H_bb.h"
#include "cs-ratios/Tevatron.R_H_gg.h"
#include "cs-ratios/Tevatron.R_HWp_csb.h"
#include "cs-ratios/Tevatron.R_HWm_dub.h"
#include "cs-ratios/Tevatron.R_HWm_scb.h"
#include "cs-ratios/Tevatron.R_HWp_udb.h"
#include "cs-ratios/Tevatron.R_HZ_bbb.h"
#include "cs-ratios/Tevatron.R_HZ_ccb.h"
#include "cs-ratios/Tevatron.R_HZ_ddb.h"
#include "cs-ratios/Tevatron.R_HZ_ssb.h"
#include "cs-ratios/Tevatron.R_HZ_uub.h"

#include "cs-ratios/LHC7TeV.R_H_bb.h"
#include "cs-ratios/LHC7TeV.R_H_gg.h"
#include "cs-ratios/LHC7TeV.R_HWp_csb.h"
#include "cs-ratios/LHC7TeV.R_HWm_dub.h"
#include "cs-ratios/LHC7TeV.R_HWm_scb.h"
#include "cs-ratios/LHC7TeV.R_HWp_udb.h"
#include "cs-ratios/LHC7TeV.R_HZ_gg.h"
#include "cs-ratios/LHC7TeV.R_HZ_bbb.h"
#include "cs-ratios/LHC7TeV.R_HZ_ccb.h"
#include "cs-ratios/LHC7TeV.R_HZ_ddb.h"
#include "cs-ratios/LHC7TeV.R_HZ_ssb.h"
#include "cs-ratios/LHC7TeV.R_HZ_uub.h"
#include "cs-ratios/LHC7TeV.R_HVBF_WW.h"
#include "cs-ratios/LHC7TeV.R_HVBF_ZZ.h"

! >> include fit functions for SM cross sections and branching ratios
#include "theory_BRfunctions.F"
#include "theory_XS_SM_functions.f"
#include "Tevatron.sigma_bg_Hb.h"
#include "Tevatron.sigma_bg_Hb.ptmin15.etamax2.h"
#include "Tevatron.sigma_bg_Hb.ptmin20.etamax2.5.h"
#include "Tevatron.sigma_bg_Hb.ptmin15.etamax2.5.h"
#include "Tevatron.sigma_bg_Hb.ptmin12.etamax5.h"
! <<


!***********************************************************
	subroutine check_TEV_bound(allowed,result_flag,
     &		mlratio,obsratio,most_sens_predratio,
     &		num_H_combined,final_h_comb,model_R_sig_BR)
!***********************************************************
! Output:
!	allowed : logical variable, TRUE if scenario is allowed at
!		95% confidence level (This is determined, using the procedure
!	 	described by Philipp Bechtle.), FALSE otherwise.
!	result_flag
!		1 if point is allowed, 
!		0 if point is not allowed
!	       -1 otherwise (theoretically inaccessible, etc.)
!		nTEV_NSCHN: # of single Higgs search channels
!		TEV_NDCHN: # of double Higgs search channels
!	mlratio : gives information about which table was used for the 
!		experimental comparison.
!	obsratio,most_sens_predratio,num_H_combined,final_h_comb,model_R_sig_BR
!--------------------------------
	implicit none 
#include "input_cb.h"
	logical allowed,predicted_limit
	logical useHAD,useLEP,useSingH

	integer my_maxloc
	
	logical table_applicable(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2)

	integer result_flag,num_H_combined
	integer index,baseindex
	integer i,j,k,n,m,ndat,ios,mlratio,mlindex,nhelp,chan,output_chan,
     &		offset,chani,chann,number_TEV_channels,TEV_analysis_number,runid
	integer mlratiotemp(1)	
	double precision R_sig_BR(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2)
        double precision R_sig_BR_sing(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2)
	double precision R_sigmaBR_mean(TEV_NSneutCHN*NHMAX+TEV_NDCHN*NHMAX**2)
        double precision dummy,dummy2
	double precision R_sig_BR_val,R_sig_BR_sing_val,norm
        double precision predratio(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2)
	double precision most_sens_predratio
	double precision obsratio
! fit functions for SM cross sections and branching ratios
	double precision SMBR_HWW
	double precision SMBR_Hbb
	double precision SMBR_Hmumu
	double precision SMBR_Htautau
        double precision SMBR_Hgamgam

	double precision SMCS_tev_HW
	double precision SMCS_tev_HZ
	double precision SMCS_tev_gg_H
	double precision SMCS_tev_bb_H
        double precision SMCS_tev_bg_Hb
        double precision SMCS_tev_bg_Hb_c1
        double precision SMCS_tev_bg_Hb_c2
        double precision SMCS_tev_bg_Hb_c3
        double precision SMCS_tev_bg_Hb_c4
        double precision SMCS_tev_vbf_H
        double precision SMCS_tev_ttH

	double precision SMCS_lhc7_HW
	double precision SMCS_lhc7_HZ
	double precision SMCS_lhc7_gg_H
	double precision SMCS_lhc7_bb_H
        double precision SMCS_lhc7_vbf_H
        double precision SMCS_lhc7_ttH
! Decay BRs of W+/- and Z
	double precision BR_Zll,BR_Ztautau,BR_Znunu,BR_Zjj,BR_Wlnu,BR_Wjj,BR_Wtaunu
  
	integer findi,findj,TEV_reaction_number
	
	logical higgs_combination(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2,NHMAX),final_h_comb(NHMAX)
	integer sim_mass_sum(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2)
        double precision Mh_avg(TEV_NSCHN*NHMAX),delta_Mh(TEV_NSneutCHN+TEV_NDCHN),delta_Mhp
	double precision log2dble,model_R_sig_BR
	double precision Mhmin_SMcalc,Mhmax_SMcalc
	double precision MHplusmin_SMcalc,MHplusmax_SMcalc

#include "tables-indexing-tev_cb.h"

	Mhmin_SMcalc=60d0
	Mhmax_SMcalc=1001d0
	MHplusmin_SMcalc=1d0
	MHplusmax_SMcalc=1000d0

! decay BRs of Z and W bosons
!BR_Zll = sum(l=e,mu) BR(Z ->l+ l-) source: Yao et al. J Phys G 33 (2006) 1
	BR_Zll=(3.363d0+3.366d0)/100d0
!BR_Ztautau source: Amsler et al. PLB (2008) 1
	BR_Ztautau=3.370d0/100d0
!BR_Znunu = sum(l=e,mu,tau) BR(Z ->nu_l nu_l-bar)
	BR_Znunu=20d0/100d0
!BR_Wlnu = sum(l=e,mu) BR(W+ ->l + nu_l) = BR(W- ->l- + nu_l-bar)
	BR_Wlnu=(10.75d0+10.57d0)/100d0
!BR_Wtaunu =  BR(W+ ->tau+ nu_tau) = BR(W- -> tau- nu_tau-bar)
	BR_Wtaunu=(11.25d0)/100d0
! BRs W,Z->hadrons from Yao et al. J Phys G 33 (2006) 1
	BR_Wjj = 67.60d0/100d0
	BR_Zjj = 69.91d0/100d0

c deactivated	delta_Mhp = delta_Mhplus_TEV
	delta_Mhp = 0d0

        call determine_topology_flags(whichexpt,
     &          useHAD,useLEP,useSingH)


	do m=0,nTEV_NSneutCHN-1,1
	 delta_Mh(m+1)=delta_Mh_TEV
	do n=1,NHIGGS
	 R_sig_BR_sing(n+NHIGGS*m)=0d0
         R_sig_BR(n+NHIGGS*m)=0d0
	 sim_mass_sum(n+NHIGGS*m)=0
	 R_sigmaBR_mean(n+NHIGGS*m)=0d0
	 do i=1,NHIGGS
          higgs_combination(n+NHIGGS*m,i)=.FALSE.
	 enddo
	enddo
	enddo

	offset = nTEV_NSneutCHN*NHIGGS
	do m=0,nTEV_NScharCHN-1,1
	do n=1,NHPLUS
	 R_sig_BR_sing(offset+n+NHPLUS*m)=0d0
         R_sig_BR(offset+n+NHPLUS*m)=0d0
	 sim_mass_sum(offset+n+NHPLUS*m)=0
	 do i=1,NHPLUS
          higgs_combination(offset+n+NHPLUS*m,i)=.FALSE.
	 enddo
	enddo
	enddo

        offset = nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS
	do m=0,nTEV_NDCHN-1,1
	do n=1,NHIGGS**2
	 R_sig_BR_sing(offset+n+m*NHIGGS**2)=0d0
	 R_sig_BR(offset+n+m*NHIGGS**2)=0d0
	 do i=1,NHIGGS
	  higgs_combination(offset+n+m*NHIGGS**2,i)=.FALSE.
         enddo
	enddo				
	enddo
	


! R_sig_BR(n) will be compared to the S95 values in the Tevatron tables


	do n=1,NHIGGS
	    if( (Mh(n) .ge. Mhmin_SMcalc) .and. (Mh(n) .le. Mhmax_SMcalc) ) then 
	      do m=0,nTEV_NSneutCHN-1,1
	       call check_TEV_applicability(table_applicable(n+NHIGGS*m), 
     &					m+1, n, R_sigmaBR_mean(n+NHIGGS*m),delta_Mh(m+1))
cdel check	      write(*,*)'tablenum, delta_Mh=',m+1,delta_Mh(m+1)
	      enddo
	    endif 
	enddo
	do n=1,NHPLUS
	    if( (MHplus(n) .ge. MHplusmin_SMcalc) 
     &		.and. (MHplus(n) .le. MHplusmax_SMcalc) ) then 
	      do m=0,nTEV_NScharCHN-1,1
	       call check_TEV_applicability(
     &			table_applicable(NHIGGS*nTEV_NSneutCHN+n+NHPLUS*m), 
     &			nTEV_NSneutCHN+m+1, n, dummy, dummy2)
	      enddo
	    endif 
	enddo
	if(.not. useSingH) then
	 do n=1,NHIGGS**2
	  i=findi(NHIGGS,n)
	  j=findj(NHIGGS,n)
	    if( (Mh(j) .ge. Mhmin_SMcalc) .and. (Mh(j) .le. Mhmax_SMcalc) ) then 
	      do m=0,nTEV_NDCHN-1,1
	       offset=NHIGGS*nTEV_NSneutCHN+NHPLUS*nTEV_NScharCHN
	       call check_TEV_applicability(table_applicable(n+m*NHIGGS**2+offset), 
     &			nTEV_NSCHN+m+1, n, R_sigmaBR_mean(n+m*NHIGGS**2+offset),delta_Mh(m+1))
	      enddo
	    endif
	 enddo
        endif



! a0) calc single sigma x BR values (no combinations of near mass Higgs bosons)
!    single Higgs analyses
!     neutral Higgs analyses
	do i=1,NHIGGS
	   if( (Mh(i) .ge. Mhmin_SMcalc) .and. (Mh(i) .le. Mhmax_SMcalc) ) then 

! LHC analyses
! p p -> g g -> H -> W W
	   	  R_sig_BR_sing_val=
     &			CS_lhc7_hj_ratio(i)*( SMCS_lhc7_gg_H(Mh(i)) + SMCS_lhc7_bb_H(Mh(i)) ) 
     &			 *BR_hjWW(i)
#ifdef ATLAS2011_134 (assuming gg -> H dominates)
		if((nATLAS2011_134) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef ATLAS2011_052 (assuming gg -> H dominates)
		if((nATLAS2011_052) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CMS1102_5429 (assuming gg -> H dominates)
		if((nCMS1102_5429) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1))=R_sig_BR_sing_val
                endif
#endif


! p p -> H(b), H -> tau tau
                  R_sig_BR_sing_val=
     &             CS_lhc7_hj_ratio(i)*( SMCS_lhc7_gg_H(Mh(i)) + SMCS_lhc7_bb_H(Mh(i)) ) 
     &                  *BR_hjtautau(i)                          
#ifdef ATLAS1107_5003
                if((nATLAS1107_5003) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1107_5003) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CMS1104_1619
                if((nCMS1104_1619) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1104_1619) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CMS11_029
                if((nCMS11_029) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS11_029) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef ATLAS2011_132
                if((nATLAS2011_132) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_132) -1))=R_sig_BR_sing_val
                endif
#endif


! Tevatron analyses
! D06220, CDF10239, D01012_0874, CDF0906_5613: p p-bar -> WH, H -> b b-bar, W -> l nu
	     	  R_sig_BR_sing_val=
     &			CS_tev_hjW_ratio(i)*SMCS_tev_HW(Mh(i))*BR_hjbb(i)

#ifdef D06220
		if((nD06220) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06220) -1))=R_sig_BR_sing_val
		endif
#endif
#ifdef CDF10239
		if((nCDF10239) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10239) -1))=R_sig_BR_sing_val
		endif
#endif
#ifdef D01012_0874
		if((nD01012_0874) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01012_0874) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF0906_5613
		if((nCDF0906_5613) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF0906_5613) -1))=R_sig_BR_sing_val
                endif
#endif


! CDF1009_3047, CDF10235, D06166, D01008_3564 : p p-bar -> ZH -> l l b b-bar
	          R_sig_BR_sing_val=
     &                  CS_tev_hjZ_ratio(i)*SMCS_tev_HZ(Mh(i))*BR_hjbb(i)
#ifdef CDF1009_3047
		if((nCDF1009_3047) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF1009_3047) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF10235
		if((nCDF10235) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10235) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D06166
		if((nD06166) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06166) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D01008_3564
		if((nD01008_3564) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01008_3564) -1))=R_sig_BR_sing_val
                endif
#endif


! CDF0809_3930, CDF_D0_1005_3216, D06219singHWW, CDF10599singHWW, : p p-bar -> H -> W W
	   	  R_sig_BR_sing_val=
     &			CS_tev_hj_ratio(i)*( SMCS_tev_gg_H(Mh(i)) + SMCS_tev_bb_H(Mh(i)) ) 
     &			 *BR_hjWW(i)
#ifdef CDF0809_3930
		if((nCDF0809_3930) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF_D0_1005_3216
		if((nCDF_D0_1005_3216) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1005_3216) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D06219singHWW
		if((nD06219singHWW) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06219singHWW) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF10599singHWW
		if((nCDF10599singHWW) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10599singHWW) -1))=R_sig_BR_sing_val
                endif
#endif


! CDF10105, D05726 : p p-bar -> b H, H -> b b-bar ([sigma x BR/sigma limit)
	   	  R_sig_BR_sing_val=
     &				CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb(Mh(i))*BR_hjbb(i) 
#ifdef CDF10105
                if((nCDF10105) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10105) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D05726
                if((nD05726) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05726) -1))=R_sig_BR_sing_val
                endif
#endif


! D01011_1931, CDF1106_4782 : p p-bar -> b H, H -> b b-bar (absolute sigma x BR limit)
#ifdef D01011_1931
                if((nD01011_1931) .gt. 0) then
	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01011_1931) -1))=
     & 			CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb_c2(Mh(i))*BR_hjbb(i) 
                endif
#endif
#ifdef CDF1106_4782
                if((nCDF1106_4782) .gt. 0) then
	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF1106_4782) -1))=
     & 			CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb_c1(Mh(i))*BR_hjbb(i) 
                endif
#endif


! 16 : p p-bar -> b H, H -> b b-bar (absolute sigma x BR limit)
!      the SM c.s. quoted in the CDF paper is a factor 0.7 lower than my c.s.
!      The CDF note 9284 result is also implemented as tab 10.
!      Table 16 was for checking whether the the absolute limit is consistent.
!      It is! So it should be switched off again.
!	   	  R_sig_BR_sing(i+NHIGGS*15)=
!     &               CS_tev_hjb_ratio(i)*0.7d0*SMCS_tev_bg_Hb_c1(Mh(i))*BR_hjbb(i) 


! D01106_4555, CDF0906_1014, D05740, CDF10099_D06063 : p p-bar -> H -> tau tau (absolute sigma x BR limit)
                  R_sig_BR_sing_val=
     &             CS_tev_hj_ratio(i)*( SMCS_tev_gg_H(Mh(i)) + SMCS_tev_bb_H(Mh(i)) ) 
     &                  *BR_hjtautau(i)                          
#ifdef D01106_4555
                if((nD01106_4555) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01106_4555) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF0906_1014
                if((nCDF0906_1014) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF0906_1014) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D05740
                if((nD05740) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05740) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef CDF10099_D06063
                if((nCDF10099_D06063) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10099_D06063) -1))=R_sig_BR_sing_val
                endif
#endif



! CDF7307v3, D05873 : p p-bar -> WH, H -> WW 
	   	  R_sig_BR_sing_val= 
     &			CS_tev_hjW_ratio(i)*SMCS_tev_HW(Mh(i))*BR_hjWW(i)

#ifdef CDF7307v3
                if((nCDF7307v3) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF7307v3) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D05873
                if((nD05873) .gt. 0) then
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05873) -1))=R_sig_BR_sing_val
                endif
#endif



! D00806_0611 : p p-bar -> H -> Z gamma
#ifdef D00806_0611
                if((nD00806_0611) .gt. 0) then  
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00806_0611) -1))=
     &			CS_tev_hj_ratio(i)*( SMCS_tev_gg_H(Mh(i))  
     &				+ SMCS_tev_bb_H(Mh(i)) )*BR_hjZga(i)
                endif
#endif



! D06083 : p p-bar -> b H, H -> tau tau [sigma x BR]/sigma_SM limit
#ifdef D06083
                if((nD06083) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06083) -1))=
     &			CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb(Mh(i))*BR_hjtautau(i)
                endif
#endif


! D01106_4885, D05985, D06083abslim, D05974 : p p-bar -> b H, H -> tau tau (absolute sigma x BR limit)
	   	  R_sig_BR_sing_val=
     &            	CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb_c3(Mh(i))*BR_hjtautau(i) 

#ifdef D01106_4885
                if((nD01106_4885) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01106_4885) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D05985
                if((nD05985) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05985) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D06083abslim
                if((nD06083abslim) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06083abslim) -1))=R_sig_BR_sing_val
                endif
#endif
#ifdef D05974
                if((nD05974) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05974) -1))=R_sig_BR_sing_val
                endif
#endif


! p p-bar -> b H, H -> b b-bar & tau tau combined, 
! absolute sigma(p pbar -> H b) limit in pikobarn, 
! 2d table in mh and BR(H-> tau tau) assuming BR(H-> tau tau) + BR(H-> b b) = 1
	   	  R_sig_BR_sing_val=
     &            	CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb_c4(Mh(i))

#ifdef D06227
                if((nD06227) .gt. 0) then  
		  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06227) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06227) -1)))
     &			*R_sig_BR_sing_val
cdel	 	write(*,*) i,Mh(i),R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06227) -1)),BR_hjtautau(i)
                endif
#endif



! D05739 : p p-bar -> ttH -> ttbb
#ifdef D05739
                if((nD05739) .gt. 0) then  
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05739) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD05739) -1))) 
     &			*CS_tev_tthj_ratio(i)*SMCS_tev_ttH(Mh(i)) 
     &		 	*BR_hjbb(i)
                endif
#endif

#ifdef CDF10574
                if((nCDF10574) .gt. 0) then  
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10574) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10574) -1))) 
     &			*CS_tev_tthj_ratio(i)*SMCS_tev_ttH(Mh(i)) 
     &		 	*BR_hjbb(i)
                endif
#endif



! model dependent limits

! fermiophobic Higgs model analyses
!temporary removed !D00803_1514 : p p-bar -> H -> gamma gamma (absolute sigma x BR limit)
!temporary removed #ifdef D00803_1514
!temporary removed                 if((nD00803_1514) .gt. 0) then  
!temporary removed                   R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00803_1514) -1))=
!temporary removed      &			 ( CS_tev_hj_ratio(i)*( SMCS_tev_gg_H(Mh(i))  + SMCS_tev_bb_H(Mh(i)) )
!temporary removed      &			  +CS_tev_hjW_ratio(i)*SMCS_tev_HW(Mh(i)) 
!temporary removed      &	 	  	+CS_tev_hjZ_ratio(i)*SMCS_tev_HZ(Mh(i)) 
!temporary removed      &		  	+CS_tev_vbf_ratio(i)*SMCS_tev_vbf_H(Mh(i)) ) 
!temporary removed      &		 	*BR_hjgaga(i)
!temporary removed 		   endif
!temporary removed #endif



! SM combined analyses
! LHC analyses
#ifdef ATLAS1108_5064
                if((nATLAS1108_5064) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5064) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5064) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5064) -1))
                endif
#endif
#ifdef ATLAS1109_3357
                if((nATLAS1109_3357) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3357) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3357) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3357) -1))
                endif
#endif
#ifdef ATLAS1109_3615
                if((nATLAS1109_3615) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3615) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3615) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1109_3615) -1))
                endif
#endif
#ifdef ATLAS1202_1415
                if((nATLAS1202_1415) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1415) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1415) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1415) -1))
                endif
#endif
#ifdef ATLAS1202_1414
                if((nATLAS1202_1414) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1414) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1414) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1414) -1))
                endif
#endif
#ifdef ATLAS1108_5895
                if((nATLAS1108_5895) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5895) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5895) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1108_5895) -1))
                endif
#endif
#ifdef ATLAS2011_133
                if((nATLAS2011_133) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_133) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_133) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_133) -1))
                endif
#endif
#ifdef ATLAS2011_103
                if((nATLAS2011_103) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_103) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_103) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_103) -1))
                endif
#endif
#ifdef CMS11_031
                if((nCMS11_031) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS11_031) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS11_031) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS11_031) -1))
                endif
#endif
#ifdef ATLAS2011_112
                if((nATLAS2011_112) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_112) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_112) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_112) -1))
                endif
#endif
#ifdef ATLAS2011_135
                if((nATLAS2011_135) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_135) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_135) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_135) -1))
                endif
#endif
#ifdef ATLAS1106_2748
                if((nATLAS1106_2748) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1106_2748) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1106_2748) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1106_2748) -1))
                endif
#endif
#ifdef ATLAS1109_5945
                if((nATLAS1109_5945) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1109_5945) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1109_5945) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1109_5945) -1))
                endif
#endif
#ifdef ATLAS2011_163
                if((nATLAS2011_163) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_163) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_163) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_163) -1))
                endif
#endif
#ifdef ATLAS1202_1408
                if((nATLAS1202_1408) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1408) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1408) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1202_1408) -1))
                endif
#endif
#ifdef ATLAS2011_148
                if((nATLAS2011_148) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_148) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_148) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_148) -1))
                endif
#endif
#ifdef ATLAS1112_2577
                if((nATLAS1112_2577) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS1112_2577) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS1112_2577) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS1112_2577) -1))
                endif
#endif
#ifdef ATLAS2011_157_CMS11_023
                if((nATLAS2011_157_CMS11_023) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nATLAS2011_157_CMS11_023) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nATLAS2011_157_CMS11_023) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nATLAS2011_157_CMS11_023) -1))
                endif
#endif
#ifdef CMS11_011
                if((nCMS11_011) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS11_011) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS11_011) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS11_011) -1))
                endif
#endif
#ifdef CMS1202_1488
                if((nCMS1202_1488) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1488) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1488) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1488) -1))
                endif
#endif
#ifdef CMS1202_1489
                if((nCMS1202_1489) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1489) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1489) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1489) -1))
                endif
#endif
#ifdef CMS1202_1997
                if((nCMS1202_1997) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1997) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1997) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1997) -1))
                endif
#endif
#ifdef CMS1202_3478
                if((nCMS1202_3478) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_3478) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_3478) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_3478) -1))
                endif
#endif
#ifdef CMS1202_1416low
                if((nCMS1202_1416low) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416low) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416low) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416low) -1))
                endif
#endif
#ifdef CMS1202_1416hi
                if((nCMS1202_1416hi) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416hi) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416hi) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1416hi) -1))
                endif
#endif
#ifdef CMS11_029SM
                if((nCMS11_029SM) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS11_029SM) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS11_029SM) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS11_029SM) -1))
                endif
#endif
#ifdef CMS1202_1487
                if((nCMS1202_1487) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCMS1202_1487) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCMS1202_1487) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCMS1202_1487) -1))
                endif
#endif


! Tevatron analyses
! D05757 : p p-bar -> single H/H via VBF -> W W + X -> l l +X
#ifdef D05757
                if((nD05757) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05757) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD05757) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD05757) -1))
                endif
#endif


! CDF10599, D05871, D01001_4481, CDF1001_4468, CDF_D0_1001_4162 : p p-bar -> H + X -> W W + X
#ifdef CDF10599
                if((nCDF10599) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10599) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10599) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10599) -1))
                endif
#endif
#ifdef D05871
                if((nD05871) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05871) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD05871) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD05871) -1))
                endif
#endif
#ifdef D01001_4481
                if((nD01001_4481) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01001_4481) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD01001_4481) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD01001_4481) -1))
                endif
#endif
#ifdef CDF1001_4468
                if((nCDF1001_4468) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF1001_4468) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF1001_4468) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF1001_4468) -1))
                endif
#endif
#ifdef CDF_D0_1001_4162
                if((nCDF_D0_1001_4162) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1001_4162) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1001_4162) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1001_4162) -1))
                endif
#endif

! CDF_D0_1108_3331 : p p-bar -> H + X -> W W + X abs. limit 
#ifdef CDF_D0_1108_3331
                if((nCDF_D0_1108_3331) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1108_3331) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1108_3331) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1108_3331) -1))
     &			*( SMCS_tev_gg_H(Mh(i)) + SMCS_tev_bb_H(Mh(i)) )
     &			*SMBR_HWW(Mh(i))
                endif
#endif



! D06219 : p p-bar -> H + X -> W W / Z Z + X
#ifdef D06219
                if((nD06219) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06219) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06219) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06219) -1))
                endif
#endif

! D06179 : p p-bar -> H + X -> W W + X
#ifdef D06179
                if((nD06179) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06179) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06179) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06179) -1))
                endif
#endif

! D06183 : p p-bar -> H + X -> W W /gamma gamma/tau tau/Z Z + X
#ifdef D06183
                if((nD06183) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06183) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06183) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06183) -1))
                endif
#endif


! D01107_1268 : p p-bar -> VH -> VVV -> same sign di-lepton(e,mu) (V=W,Z)
#ifdef D01107_1268
                if((nD01107_1268) .gt. 0) then
           	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD01107_1268) -1))=
     &			log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD01107_1268) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD01107_1268) -1))
                endif
#endif



! CDF10583, D06223, D00912_5285, CDF0911_3935 : p p-bar -> WH/ZH, H -> b b-bar
#ifdef CDF10583
                if((nCDF10583) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10583) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10583) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10583) -1))
                endif
#endif
#ifdef D06223
                if((nD06223) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06223) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06223) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06223) -1))
                endif
#endif
#ifdef D00912_5285
                if((nD00912_5285) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00912_5285) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD00912_5285) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD00912_5285) -1))
                endif
#endif
#ifdef CDF0911_3935
                if((nCDF0911_3935) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF0911_3935) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF0911_3935) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF0911_3935) -1))
                endif
#endif
#ifdef CDF10596
                if((nCDF10596) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10596) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10596) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10596) -1))
                endif
#endif


! p p-bar -> H -> gamma gamma, SM combined
#ifdef D06177
                if((nD06177) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06177) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06177) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06177) -1))
                endif
#endif
#ifdef D00901_1887
                if((nD00901_1887) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00901_1887) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD00901_1887) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD00901_1887) -1))
                endif
#endif
#ifdef CDF10485
                if((nCDF10485) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10485) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10485) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10485) -1))
                endif
#endif
#ifdef CDFD0_1107_4960
                if((nCDFD0_1107_4960) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDFD0_1107_4960) -1))=
     &		  	log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDFD0_1107_4960) -1)))
     &			*R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDFD0_1107_4960) -1))
                endif
#endif


! CDF8961_D05536, D00712_0598: : p p-bar -> (WH/ZH, H-> b b-bar)/(H,WH, H -> W W)
#ifdef CDF8961_D05536
                if((nCDF8961_D05536) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF8961_D05536) -1))=
     &		  log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF8961_D05536) -1)))
     &		  *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF8961_D05536) -1))
                endif
#endif
#ifdef D00712_0598
                if((nD00712_0598) .gt. 0) then
                  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00712_0598) -1))=
     &		  log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD00712_0598) -1)))
     &		  *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD00712_0598) -1))
                endif
#endif


! CDF10439 : p p-bar -> (single H, H via VBF ,WH/ZH), H -> tau tau
#ifdef CDF10439
                if((nCDF10439) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10439) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10439) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10439) -1))
                endif
#endif

#ifdef D00903_4800
                if((nD00903_4800) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD00903_4800) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD00903_4800) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD00903_4800) -1))
                endif
#endif

!D05845	: p p-bar -> (W)H -> (jj)tau tau,
!			     (Z)H -> (tau tau)jj or (jj)tau tau,
!			     single H, H via VBF, H -> tau tau, SM combined
#ifdef D05845
                if((nD05845) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD05845) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD05845) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD05845) -1))
                endif
#endif

!CDF10010	
#ifdef CDF10010
                if((nCDF10010) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10010) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10010) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10010) -1))
                endif
#endif


! CDF9290_D05645 : p p-bar -> (WH/ZH, H-> b b-bar)/(H/WH, H -> W W)
!                  /(H/WH/ZH/H via VBF, H->tau tau)
!		   /(H/WH/ZH/H via VBF,H -> gamma gamma)
#ifdef CDF9290_D05645
                if((nCDF9290_D05645) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF9290_D05645) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF9290_D05645) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF9290_D05645) -1))
                endif
#endif


! CDF9465_D05754 : p p-bar -> H/WH/ZH/H via VBF, H -> W W
#ifdef CDF9465_D05754
                if((nCDF9465_D05754) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF9465_D05754) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF9465_D05754) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF9465_D05754) -1))
                endif
#endif


#ifdef CDF9999
                if((nCDF9999) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF9999) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF9999) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF9999) -1))
                endif
#endif

#ifdef D06008
                if((nD06008) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06008) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06008) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06008) -1))
                endif
#endif

#ifdef D06171
                if((nD06171) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06171) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06171) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06171) -1))
                endif
#endif

#ifdef D06229
                if((nD06229) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nD06229) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nD06229) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nD06229) -1))
                endif
#endif

#ifdef CDF10500
                if((nCDF10500) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10500) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10500) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10500) -1))
                endif
#endif

#ifdef CDF10573
                if((nCDF10573) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10573) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10573) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10573) -1))
                endif
#endif




#ifdef CDF9998_D05983
                if((nCDF9998_D05983) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF9998_D05983) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF9998_D05983) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF9998_D05983) -1))
                endif
#endif

#ifdef CDF10241_D06096
                if((nCDF10241_D06096) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF10241_D06096) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF10241_D06096) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF10241_D06096) -1))
                endif
#endif

#ifdef CDF_D0_1103_3233
                if((nCDF_D0_1103_3233) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1103_3233) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1103_3233) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1103_3233) -1))
                endif
#endif

#ifdef CDF_D0_1107_5518
                if((nCDF_D0_1107_5518) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518) -1))
                endif
#endif

#ifdef CDF_D0_1107_5518bb
                if((nCDF_D0_1107_5518bb) .gt. 0) then
 	   	  R_sig_BR_sing(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518bb) -1))=
     &			 log2dble(table_applicable(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518bb) -1)))
     &			 *R_sigmaBR_mean(i+NHIGGS*(tev_Sneut_id(nCDF_D0_1107_5518bb) -1))
                endif
#endif



	   endif
	enddo

!     charged Higgs analyses
	   offset = nTEV_NSneutCHN*NHIGGS
	
	do i=1,NHPLUS
#ifdef D00908_1811cs
          if((nD00908_1811cs) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nD00908_1811cs) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjcs(i)
	  endif
#endif
#ifdef CDF0907_1269low
          if((nCDF0907_1269low) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nCDF0907_1269low) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjcs(i)
          endif
#endif
#ifdef CDF0907_1269hi
          if((nCDF0907_1269hi) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nCDF0907_1269hi) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjcs(i)
          endif
#endif
#ifdef CDF7712
          if((nCDF7712) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nCDF7712) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
          endif
#endif
#ifdef CDF8353
          if((nCDF8353) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nCDF8353) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
          endif
#endif
#ifdef D00908_1811taunu
          if((nD00908_1811taunu) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nD00908_1811taunu) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
          endif
#endif
#ifdef ATLAS2011_094
          if((nATLAS2011_094) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nATLAS2011_094) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjcs(i)
	  endif
#endif
#ifdef ATLAS2011_138
          if((nATLAS2011_138) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nATLAS2011_138) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
	  endif
#endif
#ifdef ATLAS2011_151
          if((nATLAS2011_151) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nATLAS2011_151) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
	  endif
#endif
#ifdef CMS11_008
          if((nCMS11_008) .gt. 0) then
	    chani=offset+i+NHPLUS*(tev_Schar_id(nCMS11_008) -1)
	    R_sig_BR_sing(chani)=log2dble(table_applicable(chani))*BR_tHpjb(i)*BR_Hpjtaunu(i)
	  endif
#endif

        enddo


	



! a) calc sum of sigma x BR contributions to R_sig_BR
!   single Higgs analyses
	do n=1,NHIGGS
	    if( (Mh(n) .ge. Mhmin_SMcalc) .and. (Mh(n) .le. Mhmax_SMcalc) ) then 
	      do i=1,NHIGGS
		do runid=1,nTEV_NSneutCHN,1
	          if( (Mh(i) .ge. Mh(n)) .and. ( (Mh(i)-Mh(n)) .le. delta_Mh(runid)) )then
		    chani=i+NHIGGS*(runid -1)
	            chann=n+NHIGGS*(runid -1)
		    if( R_sig_BR_sing(chani)*R_sig_BR_sing(chann) .ne. 0d0) then
     	   	       R_sig_BR(chann)=R_sig_BR(chann)+R_sig_BR_sing(chani)	   	    
	            endif
	          endif
		enddo
	      enddo
	    endif	  
        enddo


! charged Higgs analyses:
c 	defined above:	offset = nTEV_NSneutCHN*NHIGGS

	do n=1,NHPLUS
	  if( (Mhplus(n) .ge. MHplusmin_SMcalc) .and. (Mhplus(n) .le. MHplusmax_SMcalc) ) then 
	    do i=1,NHPLUS
	      if( (MHplus(i) .ge. MHplus(n)) .and. ( (MHplus(i)-MHplus(n)) .le. delta_Mhp) )then
	        do runid=1,nTEV_NScharCHN,1
	          chani=offset+i+NHPLUS*(runid -1)
	          chann=offset+n+NHPLUS*(runid -1)
		  if( R_sig_BR_sing(chani)*R_sig_BR_sing(chann) .ne. 0d0) then
     	   	    R_sig_BR(chann)=R_sig_BR(chann)+R_sig_BR_sing(chani)
		  endif
		enddo
	      endif
	    enddo
	  endif
	enddo




! b) Determine the average Higgs mass for the Higgs combinations

!   - b1: single neutral Higgs analyses
	do m=0,nTEV_NSneutCHN-1,1
	  do n=1,NHIGGS
	    baseindex=NHIGGS*m
	    sim_mass_sum(n+baseindex)=1
            higgs_combination(n+baseindex,n)=.TRUE.
	    Mh_avg(n+baseindex)=Mh(n)
	    do i=1,NHIGGS
              if(i .ne. n) then
	        if( (Mh(i) .ge. Mh(n)) .and. ( (Mh(i)-Mh(n)) .le. delta_Mh(m+1) )
     &	 	  .and. ( R_sig_BR_sing(i+baseindex)*R_sig_BR_sing(n+baseindex) .ne. 0d0)
     &		    .and.  table_applicable(i+baseindex) ) then
	          Mh_avg(n+baseindex)=Mh_avg(n+baseindex)+Mh(i)
                  sim_mass_sum(n+baseindex)=sim_mass_sum(n+baseindex)+1
	          higgs_combination(n+baseindex,i)=.TRUE.
	        endif
	      endif
	    enddo
            Mh_avg(n+baseindex)=Mh_avg(n+baseindex)/dble(sim_mass_sum(n+baseindex))
          enddo
	enddo
!   - b2: single charged Higgs analyses
	do m=0,nTEV_NScharCHN-1,1
	  do n=1,NHPLUS
	    baseindex=NHPLUS*m+nTEV_NSneutCHN*NHIGGS
	    sim_mass_sum(n+baseindex)=1
            higgs_combination(n+baseindex,n)=.TRUE.
	    Mh_avg(n+baseindex)=MHplus(n)
	    do i=1,NHPLUS
              if(i .ne. n) then
	        if( (MHplus(i) .ge. MHplus(n)) .and. ( (MHplus(i)-MHplus(n)) .le. delta_Mhp )
     &	 	  .and. ( R_sig_BR_sing(i+baseindex)*R_sig_BR_sing(n+baseindex) .ne. 0d0) 
     &		    .and.  table_applicable(i+baseindex) ) then
	          Mh_avg(n+baseindex)=Mh_avg(n+baseindex)+MHplus(i)
                  sim_mass_sum(n+baseindex)=sim_mass_sum(n+baseindex)+1
	          higgs_combination(n+baseindex,i)=.TRUE.
	        endif
	      endif
	    enddo
            Mh_avg(n+baseindex)=Mh_avg(n+baseindex)/dble(sim_mass_sum(n+baseindex))
          enddo
	enddo




! c) multiply sigma x BR by normalization 



! single neutral Higgs analyses



	do m=0,nTEV_NSneutCHN-1,1
         do n=1,NHIGGS
	   if( (Mh_avg(n+NHIGGS*m) .ge. Mhmin_SMcalc) 
     &		.and. (Mh_avg(n+NHIGGS*m) .le. Mhmax_SMcalc) ) then 

          if(m .eq. -1) then
! if m=-1 nothing nothing is done. It is the start of an if-statment, following a string of 
! elseif statements (which might be absent, due to preprocessor decisions) 
! plus a final else statement.

! LHC analyses
#ifdef ATLAS2011_134
	  elseif(m .eq. (tev_Sneut_id(nATLAS2011_134) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1))
     &		/( SMCS_lhc7_gg_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1))) 
     &		  +SMCS_lhc7_bb_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1))) 
     &           )/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_134) -1)))
#endif
#ifdef ATLAS2011_052
	  elseif(m .eq. (tev_Sneut_id(nATLAS2011_052) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1))
     &		/( SMCS_lhc7_gg_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1))) 
     &		  +SMCS_lhc7_bb_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1))) 
     &           )/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nATLAS2011_052) -1)))
#endif
#ifdef CMS1102_5429
	  elseif(m .eq. (tev_Sneut_id(nCMS1102_5429) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1))
     &		/( SMCS_lhc7_gg_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1))) 
     &		  +SMCS_lhc7_bb_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1))) 
     &           )/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCMS1102_5429) -1)))
#endif

! Tevatron analyses
! D06220, CDF10239, D01012_0874, CDF0906_5613 : p p-bar -> WH, H -> b b-bar
#ifdef D06220
	  elseif(m .eq. (tev_Sneut_id(nD06220) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06220) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06220) -1))
     &		/SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD06220) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD06220) -1)))
#endif
#ifdef CDF10239
	  elseif(m .eq. (tev_Sneut_id(nCDF10239) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10239) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10239) -1))
     &		/SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10239) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10239) -1)))
#endif
#ifdef D01012_0874
	  elseif(m .eq. (tev_Sneut_id(nD01012_0874) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD01012_0874) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD01012_0874) -1))
     &		/SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD01012_0874) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD01012_0874) -1)))
#endif
#ifdef CDF0906_5613
	  elseif(m .eq. (tev_Sneut_id(nCDF0906_5613) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF0906_5613) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF0906_5613) -1))
     &		/SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF0906_5613) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF0906_5613) -1)))
#endif


! CDF1009_3047, CDF10235, D06166, D01008_3564 : p p-bar -> ZH, H -> b b-bar
#ifdef CDF1009_3047
	  elseif(m .eq. (tev_Sneut_id(nCDF1009_3047) -1)) then
            R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF1009_3047) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF1009_3047) -1))
     &		/SMCS_tev_HZ(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF1009_3047) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF1009_3047) -1)))
#endif
#ifdef CDF10235
	  elseif(m .eq. (tev_Sneut_id(nCDF10235) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10235) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10235) -1))
     &		/SMCS_tev_HZ(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10235) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10235) -1)))
#endif
#ifdef D06166
	  elseif(m .eq. (tev_Sneut_id(nD06166) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06166) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06166) -1))
     &		/SMCS_tev_HZ(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD06166) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD06166) -1)))
#endif
#ifdef D01008_3564
	  elseif(m .eq. (tev_Sneut_id(nD01008_3564) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD01008_3564) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD01008_3564) -1))
     &		/SMCS_tev_HZ(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD01008_3564) -1)))
     &		/SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD01008_3564) -1)))
#endif


! CDF0809_3930 : p p-bar -> H -> W W
#ifdef CDF0809_3930
	  elseif(m .eq. (tev_Sneut_id(nCDF0809_3930) -1)) then
      	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1))
     &         	/( SMCS_tev_gg_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1))) 
     &		  +SMCS_tev_bb_H(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1))) 
     &		 )/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF0809_3930) -1)))
#endif


! CDF10105, D05726 : p p-bar -> b H, H -> b b-bar ([sigma x BR/sigma limit)
#ifdef CDF10105
	  elseif(m .eq. (tev_Sneut_id(nCDF10105) -1)) then
       	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10105) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10105) -1))
     &		/SMCS_tev_bg_Hb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10105) -1)))
#endif
#ifdef D05726
	  elseif(m .eq. (tev_Sneut_id(nD05726) -1)) then
             R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05726) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05726) -1))
     &		/SMCS_tev_bg_Hb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD05726) -1)))
#endif


! D06083 : p p-bar -> b H, H -> tau tau ([sigma x BR]/sigma limit)
#ifdef D06083
	  elseif(m .eq. (tev_Sneut_id(nD06083) -1)) then
       	    R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06083) -1))=
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD06083) -1))
     &		/SMCS_tev_bg_Hb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD06083) -1)))
#endif


! CDF7307v3, D05873 : p p-bar -> WH, H -> WW
#ifdef CDF7307v3
          elseif(m .eq. (tev_Sneut_id(nCDF7307v3) -1)) then
             R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF7307v3) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF7307v3) -1))
     &          /SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF7307v3) -1)))
     &		/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF7307v3) -1)))
#endif
#ifdef D05873
          elseif(m .eq. (tev_Sneut_id(nD05873) -1)) then
             R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05873) -1))= 
     &		R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05873) -1))
     &          /SMCS_tev_HW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD05873) -1)))
     &		/SMBR_HWW(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD05873) -1)))
#endif


! D05739 : p p-bar -> ttH -> ttbb
#ifdef D05739
	  elseif(m .eq. (tev_Sneut_id(nD05739) -1)) then
      	  R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05739) -1))=R_sig_BR(n+NHIGGS*(tev_Sneut_id(nD05739) -1))
     &		/( SMCS_tev_ttH(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD05739) -1)))
     &		  *SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nD05739) -1))) 
     &		 )
#endif

#ifdef CDF10574
	  elseif(m .eq. (tev_Sneut_id(nCDF10574) -1)) then
      	  R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10574) -1))=R_sig_BR(n+NHIGGS*(tev_Sneut_id(nCDF10574) -1))
     &		/( SMCS_tev_ttH(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10574) -1)))
     &		  *SMBR_Hbb(Mh_avg(n+NHIGGS*(tev_Sneut_id(nCDF10574) -1))) 
     &		 )
#endif
	

	 endif

	  endif
         enddo
        enddo


! single charged Higgs analyses
! no multiplication by normalization needed so far

! signals with same values than others already evaluated above
! no repeated channels so far



! double Higgs analyses

	  if(.not. useSingH) then	  

	  offset=nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS

	  do n=1,NHIGGS**2
	   i=findi(NHIGGS,n)
	   j=findj(NHIGGS,n)

c Higgs j produced, Higgs j -> 2 Higgses i 
c	(i.e. decay allowed if Mh(j) > 2*Mh(i))
	    if( (Mh(j) .ge. Mhmin_SMcalc) .and. (Mh(j) .le. Mhmax_SMcalc) ) then 

#ifdef D0_0905_3381_4mu
	     chann=n+(tev_Dneut_id(nD0_0905_3381_4mu) -1)*NHIGGS**2+offset
c chann korrekt?
c	     write(*,*)'offset=',offset
c	     write(*,*)'chann=',chann
c	     write(*,*)'tev_Dneut_id(nD0_0905_3381_4mu)=',tev_Dneut_id(nD0_0905_3381_4mu)
c	     write(*,*)'i,j=',i,j
c	     write(*,*)'Mh(i)=',Mh(i)
c	     write(*,*)'Mh(j)=',Mh(j)
c             write(*,*)'CS_tev_hj_ratio(j)=',CS_tev_hj_ratio(j)
c             write(*,*)'BR_hjhihi(j,i)=',BR_hjhihi(j,i)
c             write(*,*)'BR_hjmumu(i)=',BR_hjmumu(i)
c             write(*,*)'BR_hjtautau(i)=',BR_hjtautau(i)
c             write(*,*)'table_applicable(chann)=',table_applicable(chann)
	     R_sig_BR(chann)=log2dble(table_applicable(chann))
     &	      *CS_tev_hj_ratio(j)*( SMCS_tev_gg_H(Mh(j)) + SMCS_tev_bb_H(Mh(j)) )
     &	      *BR_hjhihi(j,i)*BR_hjmumu(i)**2.0D0	
c	     write(*,*)'chann=',chann
c             write(*,*)'R_sig_BR(chann)=',R_sig_BR(chann)

#endif
#ifdef D0_0905_3381_2mu2tau
	     chann=n+(tev_Dneut_id(nD0_0905_3381_2mu2tau) -1)*NHIGGS**2+offset
c chann korrekt?
c	     write(*,*)'offset=',offset
c	     write(*,*)'chann=',chann
c	     write(*,*)'tev_Dneut_id(nD0_0905_3381_2mu2tau)=',tev_Dneut_id(nD0_0905_3381_2mu2tau)
c	     write(*,*)'i,j=',i,j
c	     write(*,*)'Mh(i)=',Mh(i)
c	     write(*,*)'Mh(j)=',Mh(j)
c            write(*,*)'CS_tev_hj_ratio(j)=',CS_tev_hj_ratio(j)
c             write(*,*)'BR_hjhihi(j,i)=',BR_hjhihi(j,i)
c             write(*,*)'BR_hjmumu(i)=',BR_hjmumu(i)
c             write(*,*)'BR_hjtautau(i)=',BR_hjtautau(i)
c             write(*,*)'table_applicable(chann)=',table_applicable(chann)
	     R_sig_BR(chann)=log2dble(table_applicable(chann))
     &	      *CS_tev_hj_ratio(j)*( SMCS_tev_gg_H(Mh(j)) + SMCS_tev_bb_H(Mh(j)) )
     &	      *BR_hjhihi(j,i)*BR_hjmumu(i)*BR_hjtautau(i)*2d0
c	     write(*,*)'chann=',chann
c             write(*,*)'R_sig_BR(chann)=',R_sig_BR(chann)

#endif



	    endif
	  enddo	               	  
	  endif



	  allowed = .TRUE.

! comparing input to the predicted Tevatron results	   	  		      
	     predicted_limit = .TRUE.

!   single neutral Higgs analyses
	   do n=1,NHIGGS
	    do k=0,nTEV_NSneutCHN-1 	   
	     runid=n+NHIGGS*k
	     if(table_applicable(runid)) then
     	 	 call check_TEV_bound1(Mh_avg(runid), 
     &	           R_sig_BR(runid),predratio(runid),k+1,runid,
     &		   higgs_combination,predicted_limit)
	     else
	       predratio(runid)=-1d0
	     endif
	    enddo
	   enddo

!   single charged Higgs analyses
	   do n=1,NHPLUS
	    do k=0,nTEV_NScharCHN-1 	   
	     runid=n+NHPLUS*k+nTEV_NSneutCHN*NHIGGS
	     if(table_applicable(runid)) then
     	 	 call check_TEV_bound1(Mh_avg(runid), 
     &	           R_sig_BR(runid),predratio(runid),nTEV_NSneutCHN+k+1,runid,
     &		   higgs_combination,predicted_limit)
	     else
	       predratio(runid)=-1d0
	     endif
	    enddo
	   enddo

!   double Higgs analyses
           if(.not. useSingH) then
           do n=1,NHIGGS**2	 	   
            i=findi(NHIGGS,n)
            j=findj(NHIGGS,n)

c check! order of i <-> j ?
	    do k=0,nTEV_NDCHN-1,1
	     runid=n+k*NHIGGS**2+nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS
	     call check_TEV_bound2(Mh(i),Mh(j),R_sig_BR(runid),predratio(runid),
     &	      k+1,predicted_limit)	    
	    enddo 	    
           enddo	  		  
	   endif


	number_TEV_channels= nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS
     &			    +nTEV_NDCHN*NHIGGS**2

#ifdef DEBUG
	do nhelp=1,number_TEV_channels,1
	    call determine_output_channel_number(2,nhelp,output_chan)
	    call write_output_channel(6,NHIGGS,NHPLUS,whichexpt,output_chan)
	    write(*,*)'   R_sig_BR=sig*BR/sig*BR_ref =',R_sig_BR(nhelp)
            write(*,*)'   R_sig_BR/S95_pred.         =',predratio(nhelp) 
	enddo
#endif

	  mlratio=my_maxloc(predratio,number_TEV_channels)

! Determine the reaction number n connected to mlratio.
! For mlratio <= nTEV_NSCHN*NHIGGS there are three reactions per table, 
! i.e. n is identical with the Higgs species.
! For mlratio >  nTEV_NSCHN*NHIGGS there are NHIGGS**2-NHIGGS reactions per table,
! i.e. n lies between 1 and NHIGGS**2

	n=TEV_reaction_number(NHIGGS,NHPLUS,mlratio)

! Determine the analysis number mlindex connected to mlratio. 
!(see TEV_analysis_number(..) for explanation)
	mlindex=TEV_analysis_number(NHIGGS,NHPLUS,mlratio)


! compare with R_sig_BR(mlratio) with experimental S95 value
        predicted_limit = .FALSE.

	if(predratio(mlratio) .gt. 0d0) then
	  if((mlratio .le. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS))then
	    call check_TEV_bound1(Mh_avg(mlratio), 
     &	     		R_sig_BR(mlratio),obsratio,mlindex,mlratio,
     &			higgs_combination,predicted_limit)
	  else
	    i=findi(NHIGGS,n)	      
	    j=findj(NHIGGS,n)
	    mlindex=mlindex-nTEV_NSneutCHN-nTEV_NScharCHN
	    call check_TEV_bound2(Mh(i),Mh(j), 
     &	     R_sig_BR(mlratio),obsratio,mlindex,predicted_limit)
	  endif
	else
	  obsratio = 0d0
	endif

        if(obsratio .lt. 1d0) then
! 		obsratio = 0d0 is considered "allowed". 
! 		This is where the tables give no exclusion, e.g. 
! 		because the Higgs mass is out of range.
	  allowed=.True.
	  result_flag=1
	else
	  allowed=.False.
	  result_flag=0
	endif

	model_R_sig_BR=R_sig_BR(mlratio)
	most_sens_predratio=predratio(mlratio)
        num_H_combined=sim_mass_sum(mlratio)
	do i=1,NHIGGS
		final_h_comb(i)=higgs_combination(mlratio,i)
	enddo

#ifdef VERBOSE
        write(*,*)'Tevatron channel with highest sensitivity:'
	call determine_output_channel_number(2,mlratio,output_chan)
	call write_output_channel(6,NHIGGS,NHPLUS,whichexpt,output_chan)
        write(*,*)'   R_sig_BR/S95_predicted =',most_sens_predratio
        write(*,*)'   R_sig_BR/S95_observed  =',obsratio
#endif

	end


!***********************************************************
	subroutine calc_neutral_CS_and_BR_from_couplings(NHIGGS,Mh,Gamma_h,
     &		gs_hjss_sq,gp_hjss_sq,
     &		gs_hjcc_sq,gp_hjcc_sq,
     &		gs_hjbb_sq,gp_hjbb_sq,
     &		gs_hjtt_sq,gp_hjtt_sq,
     &		gs_hjmumu_sq,gp_hjmumu_sq, 
     &		gs_hjtautau_sq,gp_hjtautau_sq, 
     &		g_hjWW_sq, g_hjZZ_sq, g_hjZgam_sq,g_hjgamgam_sq, 
     &		g_hjgg_sq, g_hjggZ_sq, g_hjhiZ_sq_compact,
     &          R_hjZ_ee,
     &		R_bbhj_ee,R_tautauhj_ee,
     &		R_hjhi_ee_compact,
     &          R_hj_gg,R_hj_bb,R_hjb_bg,
     &          R_hjWp_udb,R_hjWp_csb,
     &		R_hjWm_dub,R_hjWm_scb,
     &		R_hjZ_gg,
     &          R_hjZ_ddb,R_hjZ_uub,R_hjZ_ssb,
     &		R_hjZ_ccb,R_hjZ_bbb,
     &		R_sigma_tev_hj_VBF,R_sigma_tev_tthj,
     &		R_sigma_lhc7_hj_VBF,R_sigma_lhc7_tthj,
     &          BRhjssbar,BRhjccbar,BRhjbbbar,BRhjmumu,BRhjtautau,
     &		BRhjWW,BRhjZZ,BRhjZgam,BRhjgamgam,BRhjgg)
!***********************************************************
	implicit none
        integer NHIGGS,i,j,k,n

        double precision 
     &		gs_hjss_sq(NHMAX),gs_hjcc_sq(NHMAX),gs_hjbb_sq(NHMAX),
     &		gs_hjtt_sq(NHMAX),gs_hjtautau_sq(NHMAX),gs_hjmumu_sq(NHMAX),
     &		gp_hjss_sq(NHMAX),gp_hjcc_sq(NHMAX),gp_hjbb_sq(NHMAX),
     &		gp_hjtt_sq(NHMAX),gp_hjtautau_sq(NHMAX),gp_hjmumu_sq(NHMAX),
     &          g_hjWW_sq(NHMAX), g_hjZZ_sq(NHMAX),g_hjZgam_sq(NHMAX),
     &          g_hjgamgam_sq(NHMAX), g_hjgg_sq(NHMAX), g_hjggZ_sq(NHMAX),
     &          g_hjhiZ_sq(NHMAX,NHMAX)
	double precision g_hjhiZ_sq_compact((NHMAX*(NHMAX+1))/2)

        double precision Mh(NHMAX),Gamma_h(NHMAX),R_Gamma
        double precision BRhjWW(NHMAX),BRhjZZ(NHMAX),BRhjZgam(NHMAX),BRhjgamgam(NHMAX)
	double precision BRhjgg(NHMAX)
        double precision BRhjssbar(NHMAX),BRhjccbar(NHMAX)
        double precision BRhjbbbar(NHMAX),BRhjmumu(NHMAX),BRhjtautau(NHMAX)

        double precision R_hjZ_ee(NHMAX),R_bbhj_ee(NHMAX),R_tautauhj_ee(NHMAX)
        double precision R_hjhi_ee(NHMAX,NHMAX)
	double precision R_hjhi_ee_compact((NHMAX*(NHMAX+1))/2)

        double precision R_hj_gg(NHMAX),R_hj_bb(NHMAX)
        double precision R_hjb_bg(NHMAX)
        double precision R_hjWp_udb(NHMAX),R_hjWp_csb(NHMAX),
     &                   R_hjWm_dub(NHMAX),R_hjWm_scb(NHMAX)
        double precision R_hjZ_gg(NHMAX),
     &			 R_hjZ_ddb(NHMAX),R_hjZ_uub(NHMAX),
     &                   R_hjZ_ssb(NHMAX),R_hjZ_ccb(NHMAX),R_hjZ_bbb(NHMAX)
        double precision R_sigma_tev_hj_VBF(NHMAX),R_sigma_tev_tthj(NHMAX)
        double precision R_sigma_lhc7_hj_VBF(NHMAX),R_sigma_lhc7_tthj(NHMAX)
        double precision SM_ZZ_contrib_to_VBF,SM_WW_contrib_to_VBF
        double precision lhc7_rHVBF_WW, lhc7_rHVBF_ZZ
! fit functions for SM width and branching ratios
        double precision SMGamma_h
        double precision SMBR_HWW
        double precision SMBR_HZZ
        double precision SMBR_Hss
        double precision SMBR_Hcc
        double precision SMBR_Hbb
        double precision SMBR_Hmumu
        double precision SMBR_Htautau
        double precision SMBR_HZgam
        double precision SMBR_Hgamgam
        double precision SMBR_Hgg
        double precision Mhmin_SMcalc,Mhmax_SMcalc
! inverse velocity squared of lepton from Higgs decay
	double precision inv_betaf_sq
! sm fermion masses in HDECAY:
	double precision ms,mc,mbmb,mtau,mmu
	
	ms=0.105D0
	mc=1.27D0
	mbmb=4.20D0
	mtau=1.777D0
	mmu=0.105658d0

	Mhmin_SMcalc=0.8d0
	Mhmax_SMcalc=1050d0

	do i=1,NHIGGS
	BRhjssbar(i)=0d0
        BRhjccbar(i)=0d0  
	BRhjbbbar(i)=0d0
	BRhjmumu(i)=0d0
	BRhjtautau(i)=0d0
	BRhjWW(i)=0d0
	BRhjZZ(i)=0d0
	BRhjgamgam(i)=0d0
	BRhjZgam(i)=0d0
	BRhjgg(i)=0d0
	enddo

! translate g_hjhiZ_sq_compact to  g_hjhiZ_sq
        k=0
        do j=1,NHIGGS
          do i=1,NHIGGS
            if(i .le. j) then
              k=k+1
              g_hjhiZ_sq(j,i)=g_hjhiZ_sq_compact(k)
              if(i .ne. j) g_hjhiZ_sq(i,j)=g_hjhiZ_sq(j,i)
            endif
          enddo
        enddo

	do n=1,NHIGGS,1
         if( (Mh(n) .ge. Mhmin_SMcalc) .and. (Mh(n) .le. Mhmax_SMcalc) ) then 
! BRs
	  if(Gamma_h(n) .eq. 0d0) then
! if Gamma_h(n)=0 then no decay is possible.
	    R_Gamma=0d0
	  else
	    R_Gamma=SMGamma_h(Mh(n))/Gamma_h(n)
	  endif

	   if(Mh(n) .gt. 2d0*ms) BRhjssbar(n)=
     &		(gs_hjss_sq(n)+inv_betaf_sq(ms,Mh(n))*gp_hjss_sq(n))
     &				*SMBR_Hss(Mh(n))*R_Gamma

	   if(Mh(n) .gt. 2d0*mc) BRhjccbar(n)=
     &		(gs_hjcc_sq(n)+inv_betaf_sq(mc,Mh(n))*gp_hjcc_sq(n))
     &				*SMBR_Hcc(Mh(n))*R_Gamma

	   if(Mh(n) .gt. 2d0*mbmb) BRhjbbbar(n)=
     &		(gs_hjbb_sq(n)+inv_betaf_sq(mbmb,Mh(n))*gp_hjbb_sq(n))
     &				*SMBR_Hbb(Mh(n))*R_Gamma


	  if(Mh(n) .gt. 2d0*mmu) BRhjmumu(n)=
     &		(gs_hjmumu_sq(n)+inv_betaf_sq(mmu,Mh(n))*gp_hjmumu_sq(n))
     &				*SMBR_Hmumu(Mh(n))*R_Gamma

	  if(Mh(n) .gt. 2d0*mtau) BRhjtautau(n)=
     &		(gs_hjtautau_sq(n)+inv_betaf_sq(mtau,Mh(n))*gp_hjtautau_sq(n))
     &				*SMBR_Htautau(Mh(n))*R_Gamma

	   BRhjWW(n)=g_hjWW_sq(n)*SMBR_HWW(Mh(n))*R_Gamma
	   BRhjZZ(n)=g_hjZZ_sq(n)*SMBR_HZZ(Mh(n))*R_Gamma
	   BRhjZgam(n)=g_hjZgam_sq(n)*SMBR_HZgam(Mh(n))*R_Gamma
	   BRhjgamgam(n)=g_hjgamgam_sq(n)*SMBR_Hgamgam(Mh(n))*R_Gamma
	   BRhjgg(n)=g_hjgg_sq(n)*SMBR_Hgg(Mh(n))*R_Gamma
cOFF	 else
cOFF	   write(*,123) n,Mh(n)
cOFF 123	   FORMAT ('HB WARNING: conversion of eff. couplings to BRs out range for neutral Higgs #',I2,' with mass in GeV: ',G10.4)
	 endif
! CS ratios
	
	  R_hjZ_ee(n)=g_hjZZ_sq(n)

! /!\ : R_bbhj_ee and R_tautauhj_ee are currently only used if either
!	gs_.. or gp_.. is zero, because there is no LEP analysis for 
!	mixed-CP property Higgs bosons.
	  R_bbhj_ee(n)=gs_hjbb_sq(n)+gp_hjbb_sq(n)
	  R_tautauhj_ee(n)=gs_hjtautau_sq(n)+gp_hjtautau_sq(n)

	  do i=1,NHIGGS,1
	    R_hjhi_ee(n,i)=g_hjhiZ_sq(n,i)
	  enddo
	
	  R_hj_gg(n)=g_hjgg_sq(n)
! check >>
          R_hj_bb(n)=gs_hjbb_sq(n)+gp_hjbb_sq(n)

	  R_hjb_bg(n)=gs_hjbb_sq(n)+gp_hjbb_sq(n)
! check <<
	
          R_hjZ_ddb(n)=R_hjZ_ee(n)
	  R_hjZ_uub(n)=R_hjZ_ee(n)
          R_hjZ_ssb(n)=R_hjZ_ee(n)
          R_hjZ_ccb(n)=R_hjZ_ee(n)
          R_hjZ_bbb(n)=R_hjZ_ee(n)
	  R_hjZ_gg(n)=g_hjggZ_sq(n)

	  R_hjWp_udb(n)=g_hjWW_sq(n)
	  R_hjWp_csb(n)=R_hjWp_udb(n)
	  R_hjWm_dub(n)=R_hjWp_udb(n)
	  R_hjWm_scb(n)=R_hjWp_udb(n)

c relative contributuion of WW- and ZZ-fusion to VBF (in LO) for 
c p p-bar collisions at SqrtS=1.96 TeV (calcuated by Terrance with VBF@NLO):
	  SM_ZZ_contrib_to_VBF=0.23d0
	  SM_WW_contrib_to_VBF=0.77d0
	  R_sigma_tev_hj_VBF(n)= g_hjWW_sq(n)*SM_WW_contrib_to_VBF
     &		      +g_hjZZ_sq(n)*SM_ZZ_contrib_to_VBF

c relative contributuion of WW- and ZZ-fusion to VBF for 
c p p collisions at SqrtS=7 TeV (calcuated by obr with HAWK):
	  R_sigma_lhc7_hj_VBF(n)= g_hjWW_sq(n)*lhc7_rHVBF_WW(Mh(n))
     &		      +g_hjZZ_sq(n)*lhc7_rHVBF_ZZ(Mh(n))

! /!\ : R_sigma_tev_tthj is currently also used if gp_hjtt_sq is non-zero, 
!	although there is only a Tevatron analysis for CP-even Higgs bosons.
!	We assume that CP-value dependent effects don't affect 
!	the obtainable cross section limit crucially.
	  R_sigma_tev_tthj(n)=gs_hjtt_sq(n)+gp_hjtt_sq(n)

	  R_sigma_lhc7_tthj(n)=gs_hjtt_sq(n)+gp_hjtt_sq(n)

	enddo


! translate R_hjhi_ee to R_hjhi_ee_compact
        k=0
        do j=1,NHIGGS
          do i=1,NHIGGS
            if(i .le. j) then
              k=k+1
              R_hjhi_ee_compact(k)=R_hjhi_ee(j,i)
            endif
          enddo
        enddo

	end

!***********************************************************
	double precision function inv_betaf_sq(mf,mh)
!***********************************************************
	implicit none
	double precision mf,mh

	inv_betaf_sq = 1d0/(1d0-4d0*(mf/mh)**2)
	
	end


!***********************************************************
	subroutine calc_hadCS_from_partCS(NHIGGS, Mh, 
     &  	R_hj_gg, R_hj_bb, R_hjb_bg,
     &          R_hjWp_udb, R_hjWp_csb, R_hjWm_dub, R_hjWm_scb,
     &		R_hjZ_gg,
     &          R_hjZ_ddb, R_hjZ_uub, R_hjZ_ssb, R_hjZ_ccb, R_hjZ_bbb,
     &		R_sigma_tev_H, R_sigma_tev_Hb, R_sigma_tev_HW, R_sigma_tev_HZ,
     &		R_sigma_lhc7_H, R_sigma_lhc7_Hb, R_sigma_lhc7_HW, R_sigma_lhc7_HZ)
!***********************************************************
! Input: 
!	Mh(NHMAX) : the NHMAX neutral Higgs masses
!    ratio of partonic cross sections (model/SM) for the process:
!	R_hj_gg	   : g g     -> H_j
!	R_hj_bb    : b b-bar -> H_j
!	R_hjb_bg   : g b/b-bar -> H_j b/b-bar
!	R_hjWp_udb : u d-bar -> H_j W+
!	R_hjWp_csb : c s-bar -> H_j W+
!	R_hjWm_dub : d u-bar -> H_j W-
!	R_hjWm_scb : s c-bar -> H_j W-
!	R_hjZ_ddb  : d d-bar -> H_j Z
!	R_hjZ_uub  : u u-bar -> H_j Z
!	R_hjZ_ssb  : s s-bar -> H_j Z
!	R_hjZ_ccb  : c c-bar -> H_j Z
!	R_hjZ_bbb  : b b-bar -> H_j Z
!--------------------------------
! Output:
!    ratio of hadronic cross section for the processes: (Tevatron)
!	R_sigma_tev_H(NHMAX) 	: p p-bar -> H + X
!	R_sigma_tev_Hb(NHMAX) 	: p p-bar -> H b/b-bar + X
!	R_sigma_tev_HW(NHMAX) 	: p p-bar -> H W+/- + X
!	R_sigma_tev_HZ(NHMAX) 	: p p-bar -> H Z + X
!    ratio of hadronic cross section for the processes: (LHC @ 7 TeV)
!	R_sigma_lhc7_H(NHMAX) 	: p p-bar -> H + X
!	R_sigma_lhc7_Hb(NHMAX) 	: p p-bar -> H b/b-bar + X
!	R_sigma_lhc7_HW(NHMAX) 	: p p-bar -> H W+/- + X
!	R_sigma_lhc7_HZ(NHMAX) 	: p p-bar -> H Z + X
!--------------------------------
	implicit none 
	integer NHIGGS,i,n
! ratios of partonic cross sections
	double precision R_hj_gg(NHMAX),R_hj_bb(NHMAX)
        double precision R_hjb_bg(NHMAX)
	double precision R_hjWp_udb(NHMAX),R_hjWp_csb(NHMAX),
     &			 R_hjWm_dub(NHMAX),R_hjWm_scb(NHMAX)
        double precision R_hjZ_gg(NHMAX),R_hjZ_ddb(NHMAX),R_hjZ_uub(NHMAX),
     &                   R_hjZ_ssb(NHMAX),R_hjZ_ccb(NHMAX),R_hjZ_bbb(NHMAX)
	double precision most_sens_predratio
	double precision obsratio
! ratios of hadronic cross sections (new model/SM)
	double precision R_sigma_tev_HW(NHMAX),R_sigma_tev_HZ(NHMAX),R_sigma_tev_H(NHMAX),
     &			 R_sigma_tev_Hb(NHMAX)
	double precision R_sigma_lhc7_HW(NHMAX),R_sigma_lhc7_HZ(NHMAX),R_sigma_lhc7_H(NHMAX),
     &			 R_sigma_lhc7_Hb(NHMAX)
! fit functions for SM partial hadronic cross section ratios
	double precision tev_rH_bb
	double precision tev_rH_gg
	double precision tev_rHWpm_dub
	double precision tev_rHWpm_scb
	double precision tev_rHWpm_csb
	double precision tev_rHWpm_udb
	double precision tev_rHZ_bbb
	double precision tev_rHZ_ccb
	double precision tev_rHZ_ddb
	double precision tev_rHZ_ssb
	double precision tev_rHZ_uub

	double precision lhc7_rH_bb
	double precision lhc7_rH_gg
	double precision lhc7_rHWm_dub
	double precision lhc7_rHWm_scb
	double precision lhc7_rHWp_csb
	double precision lhc7_rHWp_udb
	double precision lhc7_rHZ_gg
	double precision lhc7_rHZ_bbb
	double precision lhc7_rHZ_ccb
	double precision lhc7_rHZ_ddb
	double precision lhc7_rHZ_ssb
	double precision lhc7_rHZ_uub

        double precision Mh(NHMAX),Mh_avg(NHMAX)
	double precision Mhmin_SMcalc,Mhmax_SMcalc

	Mhmin_SMcalc=50d0
	Mhmax_SMcalc=1020d0

	do i=1,NHIGGS
	R_sigma_tev_HW(i)=0d0
	R_sigma_tev_HZ(i)=0d0
	R_sigma_tev_H(i)=0d0
	R_sigma_tev_Hb(i)=0d0
	R_sigma_lhc7_HW(i)=0d0
	R_sigma_lhc7_HZ(i)=0d0
	R_sigma_lhc7_H(i)=0d0
	R_sigma_lhc7_Hb(i)=0d0
	enddo

	  do n=1,NHIGGS

	   if( (Mh(n) .ge. Mhmin_SMcalc) .and. (Mh(n) .le. Mhmax_SMcalc) ) then

	    R_sigma_tev_HW(n)=R_hjWp_udb(n)*tev_rHWpm_udb(Mh(n)) 
     &		+R_hjWp_csb(n)*tev_rHWpm_csb(Mh(n)) 
     &		+R_hjWm_dub(n)*tev_rHWpm_dub(Mh(n)) 
     &		+R_hjWm_scb(n)*tev_rHWpm_scb(Mh(n))
	    R_sigma_tev_HZ(n)=R_hjZ_ddb(n)*tev_rHZ_ddb(Mh(n)) 
     &		+R_hjZ_uub(n)*tev_rHZ_uub(Mh(n)) 
     &		+R_hjZ_ssb(n)*tev_rHZ_ssb(Mh(n)) 
     &		+R_hjZ_ccb(n)*tev_rHZ_ccb(Mh(n)) 
     &		+R_hjZ_bbb(n)*tev_rHZ_bbb(Mh(n))
	    R_sigma_tev_H(n)=R_hj_gg(n)*tev_rH_gg(Mh(n)) 
     &		+R_hj_bb(n)*tev_rH_bb(Mh(n))
	    R_sigma_tev_Hb(n)=R_hjb_bg(n)

	    R_sigma_lhc7_HW(n)=R_hjWp_udb(n)*lhc7_rHWp_udb(Mh(n)) 
     &		+R_hjWp_csb(n)*lhc7_rHWp_csb(Mh(n)) 
     &		+R_hjWm_dub(n)*lhc7_rHWm_dub(Mh(n)) 
     &		+R_hjWm_scb(n)*lhc7_rHWm_scb(Mh(n))
	    R_sigma_lhc7_HZ(n)=R_hjZ_ddb(n)*lhc7_rHZ_ddb(Mh(n)) 
     &		+R_hjZ_uub(n)*lhc7_rHZ_uub(Mh(n)) 
     &		+R_hjZ_ssb(n)*lhc7_rHZ_ssb(Mh(n)) 
     &		+R_hjZ_ccb(n)*lhc7_rHZ_ccb(Mh(n)) 
     &		+R_hjZ_bbb(n)*lhc7_rHZ_bbb(Mh(n))
     &		+R_hjZ_gg(n)*lhc7_rHZ_gg(Mh(n))
	    R_sigma_lhc7_H(n)=R_hj_gg(n)*lhc7_rH_gg(Mh(n)) 
     &		+R_hj_bb(n)*lhc7_rH_bb(Mh(n))
	    R_sigma_lhc7_Hb(n)=R_hjb_bg(n)

cOFF	   else
cOFF	    write(*,124) n,Mh(n)
cOFF 124	    FORMAT ('HB WARNING: conversion of partonic to hadronic CS ratios out range for neutral Higgs #',I2,' with mass in GeV: ',G10.4)
	   endif

	  enddo

	end


c>> uncomment if this (partially implemented) new feature should be used.
c#define USE_ONLY_SELECTED_CHANNELS
c<<
#define MAX_N_PROD_CHANNELS 5
#define MAX_N_DECAYS 6
!******************************************************************
	subroutine check_TEV_applicability(table_applicable, tablenum, higgsnum,
     &			R_sigmaBR_mean,delta_Mh)
!******************************************************************
	implicit none
	logical table_applicable,CPeven,CPodd
	integer higgsnum,n_prod_channels,n_decays,n,m,tablenum,i,index,j
	integer findi,findj
	integer ihelp
	double precision channel_used(MAX_N_PROD_CHANNELS,MAX_N_DECAYS)

	double precision my_maxval

	double precision R_sigma(MAX_N_PROD_CHANNELS),R_BR(MAX_N_DECAYS)
        double precision rel_dR_sigma(MAX_N_PROD_CHANNELS),rel_dR_BR(MAX_N_DECAYS)
	double precision rel_delta_R_sig_BR((MAX_N_DECAYS*MAX_N_PROD_CHANNELS))
	double precision R_sigma_mean,R_BR_mean,eps
	
	double precision R_sigma_tev_HW,R_sigma_tev_HZ,R_sigma_tev_H,
     &			 R_sigma_tev_H_VBF,R_sigma_tev_ttH
	double precision R_sigma_lhc7_HW,R_sigma_lhc7_HZ,R_sigma_lhc7_H,
     &			 R_sigma_lhc7_H_VBF,R_sigma_lhc7_ttH
        double precision R_BRhjbbbar,R_BRhjWW,R_BRhjZZ,R_BRhjtautau,R_BRhjgamgam
        double precision R_BRhjjj,BR_hjjj,SM_BRhjjj

	double precision max_rel_delta_R_sig_BR,R_sigmaBR_mean,delta_Mh
	double precision delta_Mh_invalue

! fit functions for SM cross sections and branching ratios
	double precision SMBR_HWW
	double precision SMBR_HZZ
	double precision SMBR_Htautau
        double precision SMBR_Hgamgam
        double precision SMBR_Hss
        double precision SMBR_Hcc
        double precision SMBR_Hbb
	double precision SMBR_Hgg

#include "input_cb.h"
#include "tables-indexing-tev_cb.h"


! The models is exactly SM-like, if for all x and y the ratios 
!	sigma(x)_model * BR_model(y)
!      ------------------------------ = R_sigma(x) * R_BR(y) 
!         sigma(x)_SM * BR_SM(y)
! are equal to the same constant.

	eps=EPS_SM_LIKENESS
! eps: tolerable maximum of individual deviations of R_sigma(x)*R_BR(y) 
!      from the mean. Eventually, this should be done Mh-dependent.
!      Suggested default value: 0.02
!      Value set in tables-nhmax.F .

#ifdef USE_ONLY_SELECTED_CHANNELS
	do n=1,MAX_N_PROD_CHANNELS
	  do m=1,MAX_N_DECAYS
	    channel_used(n,m)=0d0
	  enddo
	enddo
#endif
#ifndef USE_ONLY_SELECTED_CHANNELS
	do n=1,MAX_N_PROD_CHANNELS
	  do m=1,MAX_N_DECAYS
	    channel_used(n,m)=1d0
	  enddo
	enddo
#endif

	delta_Mh_invalue=delta_Mh
	R_sigmaBR_mean=0d0

	if(tablenum .le. nTEV_NSneutCHN) then
#ifdef DEBUG
	write(*,*)'Hadron collider analyses applicability check, Mh=',Mh(higgsnum)
#endif

c set local quantities
	 R_sigma_tev_HW=CS_tev_hjW_ratio(higgsnum)
	 R_sigma_tev_HZ=CS_tev_hjZ_ratio(higgsnum)
	 R_sigma_tev_H=CS_tev_hj_ratio(higgsnum)
	 R_sigma_tev_H_VBF=CS_tev_vbf_ratio(higgsnum)
	 R_sigma_tev_ttH=CS_tev_tthj_ratio(higgsnum)	

	 R_sigma_lhc7_HW=CS_lhc7_hjW_ratio(higgsnum)
	 R_sigma_lhc7_HZ=CS_lhc7_hjZ_ratio(higgsnum)
	 R_sigma_lhc7_H=CS_lhc7_hj_ratio(higgsnum)
	 R_sigma_lhc7_H_VBF=CS_lhc7_vbf_ratio(higgsnum)
	 R_sigma_lhc7_ttH=CS_lhc7_tthj_ratio(higgsnum)	

	 if(SMBR_Hbb(Mh(higgsnum)) .ne. 0d0) then
	  R_BRhjbbbar=BR_hjbb(higgsnum)/SMBR_Hbb(Mh(higgsnum))
	 else
	  R_BRhjbbbar=0d0
	 endif
	 if(SMBR_HWW(Mh(higgsnum)) .ne. 0d0) then
	  R_BRhjWW=BR_hjWW(higgsnum)/SMBR_HWW(Mh(higgsnum))
	 else
          R_BRhjWW=0d0
         endif
	 if(SMBR_HZZ(Mh(higgsnum)) .ne. 0d0) then
	  R_BRhjZZ=BR_hjZZ(higgsnum)/SMBR_HZZ(Mh(higgsnum))
	 else
          R_BRhjZZ=0d0
         endif
	 if(SMBR_Htautau(Mh(higgsnum)) .ne. 0d0) then
	  R_BRhjtautau=BR_hjtautau(higgsnum)/SMBR_Htautau(Mh(higgsnum))
 	 else
	  R_BRhjtautau=0d0
	 endif
	 if(SMBR_Hgamgam(Mh(higgsnum)) .ne. 0d0) then
	  R_BRhjgamgam=BR_hjgaga(higgsnum)/SMBR_Hgamgam(Mh(higgsnum))
	 else
          R_BRhjgamgam=0d0
         endif

	 BR_hjjj= BR_hjss(higgsnum)+BR_hjcc(higgsnum)
     &		 +BR_hjbb(higgsnum)+BR_hjgg(higgsnum)
	 SM_BRhjjj= SMBR_Hss(Mh(higgsnum))+SMBR_Hcc(Mh(higgsnum))
     &		   +SMBR_Hbb(Mh(higgsnum))+SMBR_Hgg(Mh(higgsnum))
	 if(SM_BRhjjj .ne. 0d0) then
	  R_BRhjjj=BR_hjjj/SM_BRhjjj
	 else
	  R_BRhjjj=0d0
	 endif

c end setting local quantities
	else
#ifdef DEBUG
	write(*,*)'Hadron collider analyses applicability check, MHplus=',MHplus(higgsnum)
#endif
	endif

	 do n=1,MAX_N_PROD_CHANNELS,1
	 do m=1,MAX_N_DECAYS,1
	 rel_delta_R_sig_BR(m+(n-1)*MAX_N_DECAYS)=0d0
	 enddo
	 enddo

c delta_Mh set to zero per default. Has to be reset to e.g. delta_Mh_invalue
c in the process of the individual applicability check
	delta_Mh=0d0


! single neutral Higgs analyses

	if(tablenum .le. nTEV_NSneutCHN) then
	  index = tev_id_Sneut(tablenum)


! LHC analyses
!**********
         if(index .eq. nATLAS1108_5064) then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif((index .eq. nATLAS1109_3357) .or. (index .eq. nATLAS2011_148)
     &		.or. (index .eq. nATLAS1112_2577)) then
!####################
	 
	  n_prod_channels=2
	  n_decays=2

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjZZ
 	  R_BR(2)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nATLAS1109_3615) then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nATLAS1202_1415) then
!####################
	 
	  n_prod_channels=4
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
 
 	  R_BR(1)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif((index .eq. nATLAS1202_1414) .or. (index .eq. nATLAS1108_5895)
     & 		.or. (index .eq. nCMS1202_1487)) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS2011_133) then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif( (index .eq. nATLAS2011_103)  
     &		.or. (index .eq. nCMS11_031) ) then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_HW
          R_sigma(2)=R_sigma_lhc7_HZ
 
 	  R_BR(1)=R_BRhjbbbar

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS2011_112) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=4

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjbbbar

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS2011_135) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=5

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjbbbar
          R_BR(5)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS1106_2748) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=3

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS1109_5945) then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS2011_163) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=4

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nATLAS1202_1408) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=3

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nATLAS2011_157_CMS11_023) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=5

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjbbbar
          R_BR(5)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS11_011) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=4

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS1202_1488) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=5

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjgamgam
          R_BR(2)=R_BRhjWW
          R_BR(3)=R_BRhjZZ
          R_BR(4)=R_BRhjbbbar
          R_BR(5)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS1202_1489) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=2

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjZZ
 	  R_BR(2)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS1202_1997) then
!####################
	 
	  n_prod_channels=5
	  if(Mh(higgsnum) .gt. 305d0) n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH
 
 	  R_BR(1)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS1202_3478) then
!####################
	 
	  n_prod_channels=2
	  n_decays=2

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjZZ
 	  R_BR(2)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif((index .eq. nCMS1202_1416low) .or. (index .eq. nCMS1202_1416hi))then
!####################
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
 
 	  R_BR(1)=R_BRhjZZ

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif
!**********
         elseif(index .eq. nCMS11_029SM) then
!####################
	 
	  n_prod_channels=5
	  n_decays=1

	  R_sigma(1)=R_sigma_lhc7_H
          R_sigma(2)=R_sigma_lhc7_H_VBF
          R_sigma(3)=R_sigma_lhc7_HW
          R_sigma(4)=R_sigma_lhc7_HZ
          R_sigma(5)=R_sigma_lhc7_ttH

 
 	  R_BR(1)=R_BRhjtautau

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


! Tevatron analyses
!**********
         elseif((index .eq. nCDF8961_D05536) .or. (index .eq. nD00712_0598)) then
!####################
	 
	  n_prod_channels=3
	  n_decays=2

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
 
 	 R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjWW


	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
	 
	  
              if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
	 elseif((index .eq. nCDF10583) .or. (index .eq. nD06223) 
     & 		.or. (index .eq. nD00912_5285) .or. (index .eq. nCDF0911_3935)
     &		.or. (index .eq. nCDF10596)) then

! Combination of only 2 production channels: HW and HZ production 
! and one decay channel: H -> bb	

	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ
 
	  R_BR(1)=R_BRhjbbbar	

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)


           if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	   else
 	 	table_applicable=.TRUE.
 	   endif


!**********
         elseif((index .eq. nCDF10439) .or. (index .eq. nD06177)
     &       	.or. (index .eq. nCDF10599) .or. (index .eq. nD05871)
     & 		.or. (index .eq. nD00901_1887) .or. (index .eq. nD01001_4481)
     &		.or. (index .eq. nCDF10485) .or. (index .eq. nCDF1001_4468)
     &		.or. (index .eq. nCDF_D0_1001_4162)
     &		.or. (index .eq. nCDFD0_1107_4960)) then
	 
	  n_prod_channels=4
	  n_decays=1

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ
          R_sigma(3)=R_sigma_tev_H
	  R_sigma(4)=R_sigma_tev_H_VBF

	  if((index .eq. nD06177) .or. (index .eq. nD00901_1887)
     &		.or. (index .eq. nCDF10485) .or. (index .eq. nCDFD0_1107_4960)) then
            R_BR(1)=R_BRhjgamgam
	  endif
	  if(index .eq. nCDF10439) then
            R_BR(1)=R_BRhjtautau
	  endif
	  if((index .eq. nCDF10599) .or. (index .eq. nD05871) 
     &	  	.or. (index .eq. nD01001_4481) .or. (index .eq. nCDF1001_4468)
     &		.or. (index .eq. nCDF_D0_1001_4162) ) then
            R_BR(1)=R_BRhjWW
	  endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06219) then
	 
	  n_prod_channels=4
	  n_decays=2

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ
          R_sigma(3)=R_sigma_tev_H
	  R_sigma(4)=R_sigma_tev_H_VBF

	  R_BR(1)=R_BRhjWW
	  R_BR(2)=R_BRhjZZ

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(1,2)=1d0
	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
	 channel_used(3,1)=1d0
	 channel_used(3,2)=1d0
	 channel_used(4,1)=1d0
	 channel_used(4,2)=1d0
#endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nCDF_D0_1108_3331) then
	 
	  n_prod_channels=1
	  n_decays=2

	  R_sigma(1)=R_sigma_tev_H

	  R_BR(1)=R_BRhjWW
	  R_BR(2)=R_BRhjZZ

#ifdef USE_ONLY_SELECTED_CHANNELS
c...	 channel_used(1,1)=1d0
#endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06179) then
	 
	  n_prod_channels=4
	  n_decays=1

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ
          R_sigma(3)=R_sigma_tev_H
	  R_sigma(4)=R_sigma_tev_H_VBF

	  R_BR(1)=R_BRhjWW

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(2,1)=1d0
	 channel_used(3,1)=1d0
	 channel_used(4,1)=1d0
#endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06183) then
	 
	  n_prod_channels=4
	  n_decays=4

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ
          R_sigma(3)=R_sigma_tev_H
	  R_sigma(4)=R_sigma_tev_H_VBF

	  R_BR(1)=R_BRhjWW
	  R_BR(2)=R_BRhjZZ
	  R_BR(3)=R_BRhjgamgam
	  R_BR(4)=R_BRhjtautau

#ifdef USE_ONLY_SELECTED_CHANNELS
c ...
#endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nD01107_1268) then
	 
	  n_prod_channels=2
	  n_decays=2

	  R_sigma(1)=R_sigma_tev_HW
          R_sigma(2)=R_sigma_tev_HZ

	  R_BR(1)=R_BRhjWW
	  R_BR(2)=R_BRhjZZ

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(1,2)=1d0
	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
#endif

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nCDF9290_D05645) then
	 
	  n_prod_channels=4
	  n_decays=4

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
 	 R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjWW
	 R_BR(3)=R_BRhjtautau
         R_BR(4)=R_BRhjgamgam

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nCDF9999) then
	 
	  n_prod_channels=4
	  n_decays=3

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
 	 R_BR(1)=R_BRhjbbbar
	 R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjWW

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(1,2)=1d0
	 channel_used(1,3)=1d0

	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
	 channel_used(2,3)=1d0

	 channel_used(3,1)=0d0
	 channel_used(3,2)=1d0
	 channel_used(3,3)=1d0

	 channel_used(4,1)=0d0
	 channel_used(4,2)=1d0
	 channel_used(4,3)=1d0
#endif


	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)


          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nCDF9465_D05754) then
	 
	  n_prod_channels=4
	  n_decays=1

	  R_sigma(1)=R_sigma_tev_H
          R_sigma(2)=R_sigma_tev_HW
	  R_sigma(3)=R_sigma_tev_HZ
          R_sigma(4)=R_sigma_tev_H_VBF
 
          R_BR(1)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nD05757) then
	 
	  n_prod_channels=2
	  n_decays=1

	  R_sigma(1)=R_sigma_tev_H
          R_sigma(2)=R_sigma_tev_H_VBF
 
 	  R_BR(1)=R_BRhjWW

	  call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD05739) then

	  if(CPeven(CP_value(higgsnum))) then
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
! For this analysis adding of Higgs channels (surley for delta_Mh < 10 GeV) is OK.
	  delta_Mh = delta_Mh_invalue

!**********
         elseif(index .eq. nCDF10574) then

	  if(CPeven(CP_value(higgsnum))) then
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
! For this analysis adding of Higgs channels (surley for delta_Mh < 10 GeV) is OK.
	  delta_Mh = delta_Mh_invalue

!**********
         elseif(index .eq. nD00903_4800) then
! remark: the first analysis where only the actually selected channels 
!	  are checked for SM-likeness
	  n_prod_channels=4
	  n_decays=3

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjbbbar 
         R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjjj


#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(1,2)=1d0
	 channel_used(1,3)=0d0

	 channel_used(2,1)=1d0
	 channel_used(2,2)=0d0
	 channel_used(2,3)=1d0

	 channel_used(3,1)=0d0
	 channel_used(3,2)=1d0
	 channel_used(3,3)=0d0

	 channel_used(4,1)=0d0
	 channel_used(4,2)=1d0
	 channel_used(4,3)=0d0
#endif

c>> check
c	write(*,*) index,'OLD calculation:'
c	write(*,*)'R_sigma_mean=',R_sigma_mean
c	write(*,*)'R_BR_mean=',R_BR_mean
c        write(*,*)'R_sigmaBR_mean=',R_sigma_mean*R_BR_mean
c	write(*,*)'rel_delta_R_sig_BR_max=',my_maxval(rel_delta_R_sig_BR,(MAX_N_DECAYS*MAX_N_PROD_CHANNELS))

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

c	write(*,*) index, 'NEW calculation:'
c	write(*,*)'R_sigma_mean=',R_sigma_mean
c	write(*,*)'R_BR_mean=',R_BR_mean
c        write(*,*)'R_sigmaBR_mean=',R_sigmaBR_mean
c	write(*,*)'rel_delta_R_sig_BR_max=',max_rel_delta_R_sig_BR
c	write(*,*)
c<<

 
          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD05845) then
! remark: the first analysis where only the actually selected channels 
!	  are checked for SM-likeness
	  n_prod_channels=4
	  n_decays=2

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjtautau
         R_BR(2)=R_BRhjjj

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(1,2)=0d0
	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
	 channel_used(3,1)=1d0
	 channel_used(3,2)=0d0
	 channel_used(4,1)=1d0
	 channel_used(4,2)=0d0
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06171) then
! remark: the first analysis where only the actually selected channels 
!	  are checked for SM-likeness
	  n_prod_channels=4
	  n_decays=3

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjtautau
         R_BR(2)=R_BRhjjj
         R_BR(3)=R_BRhjWW

#ifdef USE_ONLY_SELECTED_CHANNELS
c not determined
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif((index .eq. nD06008) .or. (index .eq. nCDF9998_D05983)) then
! remark: the first analysis where only the actually selected channels 
!	  are checked for SM-likeness
	  n_prod_channels=5
	  n_decays=5

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
         R_sigma(5)=R_sigma_tev_ttH
 
         R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjjj
         R_BR(4)=R_BRhjgamgam
         R_BR(5)=R_BRhjWW

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
         channel_used(1,2)=1d0
	 channel_used(1,3)=0d0
         channel_used(1,4)=1d0
         channel_used(1,5)=1d0

	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
         channel_used(2,3)=1d0
         channel_used(2,4)=1d0
         channel_used(2,5)=1d0

	 channel_used(3,1)=0d0
	 channel_used(3,2)=1d0
         channel_used(3,3)=0d0
         channel_used(3,4)=1d0
         channel_used(3,5)=1d0

	 channel_used(4,1)=0d0
	 channel_used(4,2)=1d0
         channel_used(4,3)=0d0
         channel_used(4,4)=1d0
         channel_used(4,5)=1d0

         channel_used(5,1)=1d0
         channel_used(5,2)=0d0
         channel_used(5,3)=0d0
         channel_used(5,4)=0d0
         channel_used(5,5)=0d0
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06229) then
	  n_prod_channels=4
	  n_decays=6

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjjj
         R_BR(4)=R_BRhjgamgam
         R_BR(5)=R_BRhjWW
         R_BR(6)=R_BRhjZZ

#ifdef USE_ONLY_SELECTED_CHANNELS
c ...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nCDF10500) then
	  n_prod_channels=2
	  n_decays=1

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
 
         R_BR(1)=R_BRhjtautau

#ifdef USE_ONLY_SELECTED_CHANNELS
c ...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nCDF10573) then
	  n_prod_channels=4
	  n_decays=2

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjWW
         R_BR(2)=R_BRhjZZ

#ifdef USE_ONLY_SELECTED_CHANNELS
c ...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nCDF10241_D06096) then
! remark: the first analysis where only the actually selected channels 
!	  are checked for SM-likeness
	  n_prod_channels=5
	  n_decays=6

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
         R_sigma(5)=R_sigma_tev_ttH
 
         R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjjj
         R_BR(4)=R_BRhjgamgam
         R_BR(5)=R_BRhjWW
	 R_BR(6)=R_BRhjZZ


#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
         channel_used(1,2)=1d0
	 channel_used(1,3)=1d0
         channel_used(1,4)=1d0
         channel_used(1,5)=1d0
         channel_used(1,6)=1d0

	 channel_used(2,1)=1d0
	 channel_used(2,2)=1d0
         channel_used(2,3)=1d0
         channel_used(2,4)=1d0
         channel_used(2,5)=1d0
         channel_used(2,6)=1d0

	 channel_used(3,1)=0d0
	 channel_used(3,2)=1d0
         channel_used(3,3)=1d0
         channel_used(3,4)=1d0
         channel_used(3,5)=1d0
         channel_used(3,6)=0d0

	 channel_used(4,1)=1d0
	 channel_used(4,2)=1d0
         channel_used(4,3)=1d0
         channel_used(4,4)=1d0
         channel_used(4,5)=1d0
         channel_used(4,6)=0d0

         channel_used(5,1)=1d0
         channel_used(5,2)=0d0
         channel_used(5,3)=0d0
         channel_used(5,4)=0d0
         channel_used(5,5)=0d0
         channel_used(5,6)=0d0
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nCDF_D0_1103_3233) then
	  n_prod_channels=4
	  n_decays=4

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
 
         R_BR(1)=R_BRhjWW
         R_BR(2)=R_BRhjZZ
         R_BR(3)=R_BRhjgamgam
         R_BR(4)=R_BRhjtautau


#ifdef USE_ONLY_SELECTED_CHANNELS
c...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nCDF_D0_1107_5518) then
	  n_prod_channels=5
	  n_decays=6

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H
	 R_sigma(4)=R_sigma_tev_H_VBF
         R_sigma(5)=R_sigma_tev_ttH
 
         R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjtautau
         R_BR(3)=R_BRhjjj
         R_BR(4)=R_BRhjgamgam
         R_BR(5)=R_BRhjWW
	 R_BR(6)=R_BRhjZZ


#ifdef USE_ONLY_SELECTED_CHANNELS
c...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif


!**********
         elseif(index .eq. nCDF_D0_1107_5518bb) then
	  n_prod_channels=4
	  n_decays=2

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
         R_sigma(3)=R_sigma_tev_H_VBF
	 R_sigma(4)=R_sigma_tev_ttH
 
         R_BR(1)=R_BRhjbbbar
         R_BR(2)=R_BRhjjj


#ifdef USE_ONLY_SELECTED_CHANNELS
c...
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif





!**********
         elseif(index .eq. nCDF10010) then
	 
	  n_prod_channels=3
	  n_decays=1

	 R_sigma(1)=R_sigma_tev_HW
         R_sigma(2)=R_sigma_tev_HZ
	 R_sigma(3)=R_sigma_tev_H_VBF
 
 	 R_BR(1)=R_BRhjbbbar

#ifdef USE_ONLY_SELECTED_CHANNELS
	 channel_used(1,1)=1d0
	 channel_used(2,1)=1d0
	 channel_used(3,1)=1d0
#endif

	call calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)

          if(max_rel_delta_R_sig_BR .gt. eps) then
	 	table_applicable=.FALSE.
 	  else
 	 	table_applicable=.TRUE.
 	  endif

!**********
         elseif(index .eq. nD06227) then

	  if( (BR_hjtautau(higgsnum) + BR_hjbb(higgsnum)) .gt. 0.98d0 ) then 
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
	  delta_Mh = delta_Mh_invalue


!**********
	 else
!####################
! if tablenum is none of the above:
                table_applicable = .TRUE.
		delta_Mh = delta_Mh_invalue

	 endif
!####################

	endif



! single charged Higgs analyses

	if((tablenum .gt. nTEV_NSneutCHN)
     &		.and. (tablenum .le. nTEV_NSneutCHN+nTEV_NScharCHN)) then
	  index = tev_id_Schar(tablenum-nTEV_NSneutCHN)

!**********
         if((index .eq. nD00908_1811cs) .or. (index .eq. nCDF0907_1269low)
     &		.or. (index .eq. nCDF0907_1269hi)
     &		.or. (index .eq. nATLAS2011_094) ) then
!####################
c Those analyses (D00908_1811cs etc.) rely on b-tagging for the evaluation 
c of the signal c selection efficiency *assuming* BR_Hpjcs=1. 
c Hence, additional b-quarks from H+ decays render the analysis inapplicable. 

c/!\: needs further improvement. Sth. like the requirement that
c	BR_tWpb + sum_n BR_tHpjb(n) .gt. 0.98d0
c     with "sum_n" a sum over all Hpj which behave similar wrt the 
c     the selection criteria used in this analysis and 
c 	BR_tWpb + BR_tHpjb(higgsnum) .gt. 0.98d0
c     if none behave similar.

c>> new implementation (based on E-Mails from 20.5.2010/26.5.2010)
	  if( (BR_Hpjtaunu(higgsnum) + BR_Hpjcs(higgsnum) .gt. 0.98d0 )
     &		.and. ( BR_tWpb + BR_tHpjb(higgsnum) .gt. 0.98d0 ) ) then 
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
c<<


!**********
         elseif((index .eq. nD00908_1811taunu) .or. (index .eq. nCMS11_008)
     &		.or. (index .eq. nCDF7712) .or. (index .eq. nCDF8353)) then
c D00908_1811taunu relies on b-tagging for the evaluation of the signal
c selection efficiency *assuming* BR_Hpjtaunu=1. Hence, additional b-quarks
c from H+ decays render the analysis inapplicable. 
c The required supression factor of 1/100 is abitrarily picked.

c/!\: needs further improvement. Sth. like the requirement that
c	BR_tWpb + sum_n BR_tHpjb(n) .gt. 0.98d0
c     with "sum_n" a sum over all Hpj which behave similar wrt the 
c     the selection criteria used in this analysis and 
c 	BR_tWpb + BR_tHpjb(higgsnum) .gt. 0.98d0
c     if none behave similar.

c>> new implementation (based on E-Mails from 20.5.2010/26.5.2010)
	  if( (BR_Hpjtaunu(higgsnum) + BR_Hpjcs(higgsnum) .gt. 0.98d0 )
     &		.and. ( BR_tWpb + BR_tHpjb(higgsnum) .gt. 0.98d0 ) ) then
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
c<<
!**********
         elseif((index .eq. nATLAS2011_138) .or. (index .eq. nATLAS2011_151)) then

c/!\: needs further improvement. Sth. like the requirement that
c	BR_tWpb + sum_n BR_tHpjb(n) .gt. 0.98d0
c     with "sum_n" a sum over all Hpj which behave similar wrt the 
c     the selection criteria used in this analysis and 
c 	BR_tWpb + BR_tHpjb(higgsnum) .gt. 0.98d0
c     if none behave similar.

c>> new implementation (based on E-Mails from 20.5.2010/26.5.2010)
	  if( (BR_tWpb + BR_tHpjb(higgsnum)) .gt. 0.98d0  ) then
		table_applicable = .TRUE.
	  else
		table_applicable = .FALSE.
	  endif
c<<

!**********
	 else
!####################
! if index is none of the above:
                table_applicable = .TRUE.

	 endif
!####################

	endif


! double neutral Higgs analyses

	if((tablenum .gt. nTEV_NSCHN)) then
	  index = tev_id_Dneut(tablenum-nTEV_NSCHN)
!**********
         if( (index .eq. nD0_0905_3381_4mu) .or. (index .eq. nD0_0905_3381_2mu2tau) )then
cdel	  write(*,*)'Applicability check: index=',index
          i=findi(NHIGGS,higgsnum)
          j=findj(NHIGGS,higgsnum)
          if(Mh(j) .gt. 2d0*Mh(i)) then
		table_applicable = .TRUE.
	   else
		table_applicable = .FALSE.
	  endif

c check if OK:
	  delta_Mh = 0d0
	

!**********
	 else
!####################
! if index is none of the above:
                table_applicable = .TRUE.

	 endif
!####################

	endif


#ifdef DEBUG
	if(table_applicable) then	
 	  write(*,*)'table ',tablenum,' applies to model point'
 	else
 	  write(*,*)'table ',tablenum,' does not apply to model point'
	endif
#endif


	end


!******************************************************************
        subroutine calc_means_maxdeviation(R_sigma,R_BR,n_prod_channels,n_decays,
     &		channel_used,max_rel_delta_R_sig_BR,R_sigmaBR_mean)
!******************************************************************
	implicit none
!input
	integer n_prod_channels,n_decays
	double precision R_sigma(MAX_N_PROD_CHANNELS),R_BR(MAX_N_DECAYS)
	double precision channel_used(MAX_N_PROD_CHANNELS,MAX_N_DECAYS)
!internal
	integer n,m
	double precision my_maxval,very_large
	double precision R_sigma_mean,R_BR_mean
        double precision rel_dR_sigma(MAX_N_PROD_CHANNELS),rel_dR_BR(MAX_N_DECAYS)
	double precision rel_delta_R_sig_BR((MAX_N_DECAYS*MAX_N_PROD_CHANNELS))
!output
	double precision max_rel_delta_R_sig_BR, R_sigmaBR_mean
!*****************************************************************
	very_large=1d10
! very_large: enromously large value in order trigger non-applicability 
! in cases where the deviation from the SM is actually infinity 
! because one of the signal channels has zero cross section.

	do n=1,MAX_N_PROD_CHANNELS,1
	do m=1,MAX_N_DECAYS,1
	  rel_delta_R_sig_BR(m+(n-1)*MAX_N_DECAYS)=0d0
	enddo
	enddo


	R_sigma_mean=0d0
	do n=1,n_prod_channels
	  R_sigma_mean=R_sigma_mean+R_sigma(n)/dble(n_prod_channels)
	enddo

	R_BR_mean=0d0
	do n=1,n_decays
          R_BR_mean=R_BR_mean+R_BR(n)/dble(n_decays)
        enddo

	R_sigmaBR_mean=R_sigma_mean*R_BR_mean

	if(R_sigmaBR_mean .eq. 0d0) then
          max_rel_delta_R_sig_BR=very_large	
	else
	
	  do n=1,n_prod_channels
	    rel_dR_sigma(n)=(R_sigma(n)-R_sigma_mean)/R_sigma_mean
	  enddo

          do n=1,n_decays
	    rel_dR_BR(n)=(R_BR(n)-R_BR_mean)/R_BR_mean
          enddo

          do n=1,n_prod_channels
	  do m=1,n_decays
	    rel_delta_R_sig_BR(m+(n-1)*n_decays)= 
     &	  	 ( rel_dR_sigma(n) 
     &	 	  +rel_dR_BR(m) 
     &	 	  +rel_dR_sigma(n)*rel_dR_BR(m) )*channel_used(n,m)
	    rel_delta_R_sig_BR(m+(n-1)*n_decays)=dabs(rel_delta_R_sig_BR(m+(n-1)*n_decays))
          enddo
	  enddo
	  max_rel_delta_R_sig_BR=
     &		my_maxval(rel_delta_R_sig_BR,(MAX_N_DECAYS*MAX_N_PROD_CHANNELS)) 
	endif

 
	end


!******************************************************************
	integer function TEV_reaction_number(NHIGGS,NHPLUS,channel)
!******************************************************************
!remark: gives the reaction number within the same analysis, i.e.
!	 a number between 1,..,NHIGGS for single Higgs analyses
!	 and      between 1,..,NHIGGS**2 for double Higgs analyses
	implicit none
	integer NHIGGS,NHPLUS,channel,chn_wo_offset
#include "tables-indexing-tev_cb.h"

	if(channel .le. nTEV_NSneutCHN*NHIGGS) then
	  TEV_reaction_number=channel-int((channel-1)/NHIGGS)*NHIGGS
	elseif((channel .gt. nTEV_NSneutCHN*NHIGGS) 
     & 		.and. (channel .le. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS)) then
	  chn_wo_offset = channel-nTEV_NSneutCHN*NHIGGS
	  TEV_reaction_number=chn_wo_offset-int((chn_wo_offset-1)/NHPLUS)*NHPLUS
	else
	  chn_wo_offset = channel-nTEV_NSneutCHN*NHIGGS-nTEV_NScharCHN*NHPLUS
	  TEV_reaction_number=chn_wo_offset-int((chn_wo_offset-1)/NHIGGS**2)*NHIGGS**2
	endif


	end


!******************************************************************
        integer function TEV_analysis_number(NHIGGS,NHPLUS,channel)
!******************************************************************
        implicit none
        integer channel,NHIGGS,NHPLUS
#include "tables-indexing-tev_cb.h"

	if(channel .le. nTEV_NSneutCHN*NHIGGS) then 
          TEV_analysis_number=1+int((channel-1)/NHIGGS)

        elseif((channel .gt. nTEV_NSneutCHN*NHIGGS)
     &         .and. (channel .le. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS)) then
          TEV_analysis_number=
     &		1+int((channel-nTEV_NSneutCHN*NHIGGS-1)/NHPLUS)+nTEV_NSneutCHN   

        elseif(channel .gt. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS) then
          TEV_analysis_number=
     &	  	1+int((channel-nTEV_NSneutCHN*NHIGGS-nTEV_NScharCHN*NHPLUS-1)/NHIGGS**2)
     &          +nTEV_NSneutCHN+nTEV_NScharCHN
        endif

	end



!******************************************************************
	subroutine check_TEV_bound1(Mh1,R_sig_BR,ratio,selec,overallid,higgs_combination,
     &		pred)
!******************************************************************
! remark: selec is expected to run from 1 to nTEV_NSneutCHN+nTEV_NScharCHN=nTEV_NSCHN
	implicit none
	logical pred
	logical higgs_combination(TEV_NSCHN*NHMAX+TEV_NDCHN*NHMAX**2,NHMAX)
	integer tabsize,pred_obs_flag
	integer i,ilow,ihigh,selec,Sid,Sid_2d,overallid
	double precision Mh1,Mh1_test,Mh1_below,R_sig_BR,ratio
        double precision S95_above,S95_below,S95_interpol
        double precision xval,yval
	double precision SMCS_tev_bg_Hb_c4

#include "tables-indexing-tev_cb.h"
#include "tables-data-tev_cb.h"
#include "input_cb.h"


	if(selec .le. nTEV_NSneutCHN) then
	  Sid=tev_Sid_Sneut(selec)
	else
	  Sid=tev_Sid_Schar(selec-nTEV_NSneutCHN)
	endif

	if(R_sig_BR .eq. 0d0) then
cnew>>	  ratio=-1d0
	  ratio=0d0
c<<
	return
	endif

	if(pred) then
	  pred_obs_flag=1
	else
	  pred_obs_flag=2
	endif

	if(.not. analysis_is_2d(selec)) then
          ratio=0.0D0
	  tabsize=nint((Mhmax(Sid)-Mhmin(Sid))/sep(Sid))+1

! check if mass is within mass range of table:
	  if((Mh1 .gt. Mhmax(Sid)) .or. (Mh1 .lt. Mhmin(Sid))) then
	    ratio=0D0
	  else	
! linear interpolate between points in table
            ilow=int((Mh1-Mhmin(Sid))/sep(Sid))+1

! check if interpolation is needed 
!	The expression in the following if-statement should be mathematically zero.
!	However, numerically, it is sometimes only nearly zero.
	    if( ((Mh1-Mhmin(Sid))/sep(Sid)+1d0-dble(ilow)) .lt. 1d-7) then
		S95_interpol=S95_1d(pred_obs_flag,Sid,ilow)
	    else
	      i=ilow	 	 
	      Mh1_below=dble(i-1)*sep(Sid)+Mhmin(Sid)
	      S95_below=S95_1d(pred_obs_flag,Sid,i)
	      S95_above=S95_1d(pred_obs_flag,Sid,i+1)
     	      S95_interpol=S95_below +(S95_above-S95_below)/sep(Sid)*(Mh1-Mh1_below) 
	    endif
! R_sig_BR is the ratio (sigma*BRs)_model/(sigma*BRs)_ref.
! R_sig_BR for the channel with the highest R_sig_BR/S95_interpol_predicted
! has to be smaller then S95_interpol_observed in order to yield an
! allowed scenario. 
! The latter is equivalent to ratio=R_sig_BR/S95_interpol_observed < 1.

!---TESTING:
!          if(pred_obs_flag.eq.2) write(*,*) 'Interpolated value =',S95_interpol  

	    ratio=R_sig_BR/S95_interpol		

	  endif 
	
	else
	  ratio=0d0

c get index of set of single Higgs analyses with 2d tables out of 
c index of set of single Higgs analyses:
	  Sid_2d = tev_Sis2d_Sid(Sid)

	  xval=Mh1
#ifdef D06227
	  yval=0d0
	  do i=1,NHIGGS
	    if(higgs_combination(overallid,i)) 
     & 		yval=yval+CS_tev_hjb_ratio(i)*SMCS_tev_bg_Hb_c4(Mh(i))*BR_hjtautau(i)
	  enddo
c R_sig_BR is here sum_i*CS_tev_hjb_ratio(i). So we don't need to calculate it
c here again.
	  yval=yval/R_sig_BR
#endif	
	  call interpol2d(xval,yval,Sid_2d,pred,S95_interpol)
	  if(S95_interpol .gt. 0d0) ratio=R_sig_BR/S95_interpol

	endif	

	end


!******************************************************************
	subroutine check_TEV_bound2(Mh1in,Mh2in, 
     &	  R_sig_BR,ratio,selec,pred)
!******************************************************************	  
! remark: selec is expected to run from 1 to nTEV_NDCHN
	implicit none
	logical pred

	integer selec,selec_2d,pred_obs_flag
	integer i,j
	double precision Mh1in,Mh2in,ratio
        double precision R_sig_BR
        double precision S95_interpol
        double precision xval,yval


#include "tables-indexing-tev_cb.h"
#include "tables-data-tev_cb.h"

	if(R_sig_BR .eq. 0d0) then
	  ratio=0d0
	  return
	endif

	if(pred) then
	  pred_obs_flag=1
	else
	  pred_obs_flag=2
	endif

c double Higgs analysis selection index is the 2d table index if 
c offset by the number of single Higgs analyses with 2s tables:
	selec_2d=nTEV_S2dTAB + selec

c>> check
c        write(*,*)'nTEV_S2dTAB=',nTEV_S2dTAB
c	write(*,*)'selec_2d=',selec_2d
c	        write(*,*)'selec=',selec
c<< check
	
#ifdef D0_0905_3381_4mu
	xval=Mh2in
	yval=Mh1in
#endif
#ifdef D0_0905_3381_2mu2tau
	xval=Mh2in
	yval=Mh1in
#endif

! check if variables are within range of table:
	if(xval .lt. XVALmin(selec_2d)) then 
	  ratio=0D0
	  return
	endif
	if(xval .gt. XVALmax(selec_2d)) then
	  ratio=0D0
          return
        endif
	if(yval .lt. YVALmin(selec_2d)) then
	  ratio=0D0
          return
        endif
	if(yval .gt. YVALmax(selec_2d)) then
	  ratio=0D0
          return
        endif

	call interpol2d(xval,yval,selec_2d,pred,S95_interpol)
	if(S95_interpol .gt. 0d0) ratio=R_sig_BR/S95_interpol

	end


******************************************************************************
	subroutine interpol2d(x,y,selec,pred,fval)
******************************************************************************
	implicit none
	logical pred
	integer selec,i,j,pred_obs_flag
	double precision x,y,xmin,xmax,dx,ymin,ymax,dy,fval
	double precision rx,ry,ryprime,g(0:1,0:1),small

	parameter(small = 1d-2)

#include "tables-data-tev_cb.h"

	fval=0d0

        if(pred) then
          pred_obs_flag=1
        else
          pred_obs_flag=2
        endif
	

ccheck	write(*,*)'selec=',selec

	xmin=XVALmin(selec)
	xmax=XVALmax(selec)
	dx=sepX(selec)

	ymin=YVALmin(selec)
	ymax=YVALmax(selec)
	dy=sepY(selec)

c check if point (x,y) is out of the table range
	if( (x .ge. xmin) .and. (x .le. xmax) 
     &	    .and. (y .ge. ymin) .and. (y .le. ymax) ) then

	  i=int((x-xmin)/dX)
	  j=int((y-ymin)/dY)

	  g(0,0)=S95_2d(pred_obs_flag,selec,i,j)
	  g(1,0)=S95_2d(pred_obs_flag,selec,i+1,j)
	  g(0,1)=S95_2d(pred_obs_flag,selec,i,j+1)
	  g(1,1)=S95_2d(pred_obs_flag,selec,i+1,j+1)

	  rx=dmod(x,dX)/dX
	  ry=dmod(y,dY)/dY

c If the separation of (x,y) from a grid point, measured as a fraction
c of grid point separation, is less than "small" (set to 1d-2) for 
c the x and the y coordinate, then the nearby grid point is taken for 
c the interpolated function value. ...

	  if((rx .le. small) .and. (ry .le. small)) then
	    fval=g(0,0)
	    return
	  elseif((rx .le. small) .and. ((1d0-ry) .le. small)) then
	    fval=g(0,1)
            return
	  elseif(((1d0-rx) .le. small) .and. (ry .le. small)) then
	    fval=g(1,0)
            return
	  elseif(((1d0-rx) .le. small) .and. ((1d0-ry) .le. small)) then
	    fval=g(1,1)
            return
	  endif

c	  write(*,*)'i=',i
c	  write(*,*)'j=',j
c	  write(*,*)'rx=',rx
c	  write(*,*)'ry=',ry

c ... Otherwise, the interpolation is done
	  if(rx .ge. ry) then
	    fval=g(0,0)+rx*(g(1,0)-g(0,0))+ry*(g(1,1)-g(1,0))
	  else
	    ryprime=ry-1d0
cdel	    write(*,*)'ryprime=',ryprime
	    fval=g(0,1)+rx*(g(1,1)-g(0,1))-ryprime*(g(0,0)-g(0,1))
	  endif

	else
	  write(*,*)'2d interpolation call out of table range'
	  write(*,*) x,'not in [',xmin,',',xmax,'] or'
	  write(*,*) y,'not in [',ymin,',',ymax,']'
	endif

	end
